((Al\ Bayan Bold) ((AlBayanBold.ttf 0 81852) (AlBayan.ttc 2 178720) (AlBayanBold.ttf 0 82200)))
((Al\ Bayan Plain) ((AlBayan.ttf 0 82080) (AlBayan.ttc 0 178720) (AlBayan.ttf 0 82432)))
((Al\ Bayan\ PUA Bold) ((AlBayan.ttc 3 178720)))
((Al\ Bayan\ PUA Plain) ((AlBayan.ttc 1 178720)))
((Al\ Nile Bold) ((Al\ Nile.ttc 1 124996)))
((Al\ Nile Regular) ((Al\ Nile.ttc 0 124996)))
((Al\ Nile\ PUA Bold) ((Al\ Nile.ttc 3 124996)))
((Al\ Nile\ PUA Regular) ((Al\ Nile.ttc 2 124996)))
((Al\ Tarikh Regular) ((Al\ Tarikh.ttc 0 76572)))
((Al\ Tarikh\ PUA Regular) ((Al\ Tarikh.ttc 1 76572)))
((Alex\ Toth Regular) ((alex-toth.ttf 0 72096)))
((Alpenkreuzer Regular) ((Alpenkreuzer.ttf 0 9780)))
((American\ Typewriter Bold) ((AmericanTypewriter.ttc 1 917120) (AmericanTypewriter.ttc 2 2906024) (AmericanTypewriter.ttc 1 1001208)))
((American\ Typewriter Condensed) ((AmericanTypewriter.ttc 4 917120) (AmericanTypewriter.ttc 3 2906024) (AmericanTypewriter.ttc 4 1001208)))
((American\ Typewriter Condensed\ Bold) ((AmericanTypewriter.ttc 2 917120) (AmericanTypewriter.ttc 4 2906024) (AmericanTypewriter.ttc 2 1001208)))
((American\ Typewriter Condensed\ Light) ((AmericanTypewriter.ttc 5 917120) (AmericanTypewriter.ttc 5 2906024) (AmericanTypewriter.ttc 5 1001208)))
((American\ Typewriter Light) ((AmericanTypewriter.ttc 3 917120) (AmericanTypewriter.ttc 1 2906024) (AmericanTypewriter.ttc 3 1001208)))
((American\ Typewriter Regular) ((AmericanTypewriter.ttc 0 917120) (AmericanTypewriter.ttc 0 2906024) (AmericanTypewriter.ttc 0 1001208)))
((Andale\ Mono Regular) ((Andale\ Mono.ttf 0 109700) (andalemo.ttf 0 105548)))
((Andika\ Basic Regular) ((AndBasR.ttf 0 250908)))
((Apex\ Lake Regular) ((Apex\ Lake\ Regular.ttf 0 381496) (ApexLake-Regular.otf 0 188600)))
((Apple\ Braille Outline\ 6\ Dot) ((Apple\ Braille\ Outline\ 6\ Dot.ttf 0 263912)))
((Apple\ Braille Outline\ 8\ Dot) ((Apple\ Braille\ Outline\ 8\ Dot.ttf 0 280980)))
((Apple\ Braille Pinpoint\ 6\ Dot) ((Apple\ Braille\ Pinpoint\ 6\ Dot.ttf 0 183080)))
((Apple\ Braille Pinpoint\ 8\ Dot) ((Apple\ Braille\ Pinpoint\ 8\ Dot.ttf 0 189668)))
((Apple\ Braille Regular) ((Apple\ Braille.ttf 0 135960)))
((Apple\ Chancery Chancery) ((Apple\ Chancery.ttf 0 336776) (Apple\ Chancery.ttf 0 335572)))
((Apple\ Color\ Emoji Regular) ((Apple\ Color\ Emoji.ttf 0 69122784) (Apple\ Color\ Emoji.ttf 0 35944652)))
((Apple\ LiGothic Medium) ((Apple\ LiGothic\ Medium.ttf 0 5802828)))
((Apple\ LiSung Light) ((Apple\ LiSung\ Light.ttf 0 8881092)))
((Apple\ SD\ Gothic\ Neo Bold) ((AppleSDGothicNeo.ttc 6 28386056) (AppleSDGothicNeo-Bold.otf 0 2379684)))
((Apple\ SD\ Gothic\ Neo ExtraBold) ((AppleSDGothicNeo.ttc 14 28386056) (AppleSDGothicNeo-ExtraBold.otf 0 2376488)))
((Apple\ SD\ Gothic\ Neo Heavy) ((AppleSDGothicNeo.ttc 16 28386056) (AppleSDGothicNeo-Heavy.otf 0 2489128)))
((Apple\ SD\ Gothic\ Neo Light) ((AppleSDGothicNeo.ttc 8 28386056) (AppleSDGothicNeo-Light.otf 0 2344104)))
((Apple\ SD\ Gothic\ Neo Medium) ((AppleSDGothicNeo.ttc 2 28386056) (AppleSDGothicNeo-Medium.otf 0 2335688)))
((Apple\ SD\ Gothic\ Neo Regular) ((AppleSDGothicNeo.ttc 0 28386056) (AppleSDGothicNeo-Regular.otf 0 2352564)))
((Apple\ SD\ Gothic\ Neo SemiBold) ((AppleSDGothicNeo.ttc 4 28386056) (AppleSDGothicNeo-SemiBold.otf 0 2322500)))
((Apple\ SD\ Gothic\ Neo Thin) ((AppleSDGothicNeo.ttc 10 28386056) (AppleSDGothicNeo-Thin.otf 0 2413980)))
((Apple\ SD\ Gothic\ Neo UltraLight) ((AppleSDGothicNeo.ttc 12 28386056) (AppleSDGothicNeo-UltraLight.otf 0 2350084)))
((Apple\ SD\ Gothic\ NeoI Bold) ((AppleSDGothicNeo.ttc 7 28386056)))
((Apple\ SD\ Gothic\ NeoI ExtraBold) ((AppleSDGothicNeo.ttc 15 28386056)))
((Apple\ SD\ Gothic\ NeoI Heavy) ((AppleSDGothicNeo.ttc 17 28386056)))
((Apple\ SD\ Gothic\ NeoI Light) ((AppleSDGothicNeo.ttc 9 28386056)))
((Apple\ SD\ Gothic\ NeoI Medium) ((AppleSDGothicNeo.ttc 3 28386056)))
((Apple\ SD\ Gothic\ NeoI Regular) ((AppleSDGothicNeo.ttc 1 28386056)))
((Apple\ SD\ Gothic\ NeoI SemiBold) ((AppleSDGothicNeo.ttc 5 28386056)))
((Apple\ SD\ Gothic\ NeoI Thin) ((AppleSDGothicNeo.ttc 11 28386056)))
((Apple\ SD\ Gothic\ NeoI UltraLight) ((AppleSDGothicNeo.ttc 13 28386056)))
((Apple\ Symbols Regular) ((Apple\ Symbols.ttf 0 1506200) (Apple\ Symbols.ttc 0 1681044) (Apple\ Symbols.ttf 0 3751668)))
((AppleGothic Regular) ((AppleGothic.ttf 0 15394584) (AppleGothic.ttf 0 15292988) (AppleGothic.ttf 0 15600596)))
((Aqua\ Kana Bold) ((AquaKana.ttc 1 36497832) (AquaKana.ttc 1 18487164) (AquaKana.ttc 1 18487652)))
((Aqua\ Kana Regular) ((AquaKana.ttc 0 36497832) (AquaKana.ttc 0 18487164) (AquaKana.ttc 0 18487652)))
((AR\ PL\ New\ Sung Regular) ((fireflysung.ttf 0 15443432)))
((AR\ PL\ UMing\ CN Light) ((uming.ttc 0 21053592)))
((AR\ PL\ UMing\ HK Light) ((uming.ttc 1 21053592)))
((AR\ PL\ UMing\ TW Light) ((uming.ttc 2 21053592)))
((AR\ PL\ UMing\ TW\ MBE Light) ((uming.ttc 3 21053592)))
((AR\ PL\ ZenKai\ Uni Regular) ((ukai.ttf 0 16480888)))
((Architext Regular) ((architxt.ttf 0 40728)))
((Arial Black) ((Arial\ Black.ttf 0 122556) (ariblk.ttf 0 118832)))
((Arial Bold) ((Arial\ Bold.ttf 0 750984) (arialbd.ttf 0 352224)))
((Arial Bold\ Italic) ((Arial\ Bold\ Italic.ttf 0 558672) (arialbi.ttf 0 226748)))
((Arial Italic) ((Arial\ Italic.ttf 0 553284) (ariali.ttf 0 207808)))
((Arial Narrow) ((Arial\ Narrow.ttf 0 179492)))
((Arial Narrow\ Bold) ((Arial\ Narrow\ Bold.ttf 0 184420)))
((Arial Narrow\ Bold\ Italic) ((Arial\ Narrow\ Bold\ Italic.ttf 0 183932)))
((Arial Narrow\ Italic) ((Arial\ Narrow\ Italic.ttf 0 184944)))
((Arial Regular) ((arial.ttf 0 367112) (Arial.ttf 0 773236)))
((Arial\ Hebrew Bold) ((ArialHBBold.ttf 0 35548) (ArialHB.ttc 1 192088)))
((Arial\ Hebrew Light) ((ArialHB.ttc 2 192088)))
((Arial\ Hebrew Regular) ((ArialHB.ttf 0 36216) (ArialHB.ttc 0 192088)))
((Arial\ Hebrew\ Desk\ Interface Bold) ((ArialHB.ttc 4 192088)))
((Arial\ Hebrew\ Desk\ Interface Light) ((ArialHB.ttc 5 192088)))
((Arial\ Hebrew\ Desk\ Interface Regular) ((ArialHB.ttc 3 192088)))
((Arial\ Hebrew\ Scholar Bold) ((ArialHB.ttc 7 192088)))
((Arial\ Hebrew\ Scholar Light) ((ArialHB.ttc 8 192088)))
((Arial\ Hebrew\ Scholar Regular) ((ArialHB.ttc 6 192088)))
((Arial\ Rounded\ MT Bold) ((Arial\ Rounded\ Bold.ttf 0 49296)))
((Arial\ Unicode\ MS Regular) ((Arial\ Unicode.ttf 0 23278008)))
((Asana\ Math Regular) ((Asana-Math.ttf 0 497852) (Asana-Math.ttf 0 483532)))
((Astroneo ASTRONEO) ((ASTRONEO.ttf 0 196208)))
((Athelas Bold) ((Athelas.ttc 3 2310148)))
((Athelas Bold\ Italic) ((Athelas.ttc 2 2310148)))
((Athelas Italic) ((Athelas.ttc 1 2310148)))
((Athelas Regular) ((Athelas.ttc 0 2310148)))
((Aurulent\ Sans Bold) ((AurulentSans-Bold.otf 0 37392)))
((Aurulent\ Sans BoldItalic) ((AurulentSans-BoldItalic.otf 0 53436)))
((Aurulent\ Sans Italic) ((AurulentSans-Italic.otf 0 52732)))
((Aurulent\ Sans Regular) ((AurulentSans-Regular.otf 0 37316)))
((Aurulent\ Sans\ Mono Regular) ((AurulentSansMono-Regular.otf 0 36492)))
((Avenir Black) ((Avenir.ttc 2 1593228) (Avenir.ttc 2 1540324)))
((Avenir Heavy) ((Avenir.ttc 4 1593228) (Avenir.ttc 4 1540324)))
((Avenir Heavy\ Oblique) ((Avenir.ttc 5 1593228) (Avenir.ttc 5 1540324)))
((Avenir Light) ((Avenir.ttc 6 1593228) (Avenir.ttc 6 1540324)))
((Avenir Light\ Oblique) ((Avenir.ttc 7 1593228) (Avenir.ttc 7 1540324)))
((Avenir Oblique) ((Avenir.ttc 9 1593228) (Avenir.ttc 10 1593228) (Avenir.ttc 9 1540324) (Avenir.ttc 10 1540324)))
((Avenir Oblique\ Black) ((Avenir.ttc 3 1593228) (Avenir.ttc 3 1540324)))
((Avenir Regular) ((Avenir.ttc 8 1593228) (Avenir.ttc 8 1540324)))
((Avenir Roman) ((Avenir.ttc 11 1593228) (Avenir.ttc 11 1540324)))
((Avenir\ Book Oblique) ((Avenir.ttc 1 1593228) (Avenir.ttc 1 1540324)))
((Avenir\ Book Regular) ((Avenir.ttc 0 1593228) (Avenir.ttc 0 1540324)))
((Avenir\ Next Bold) ((Avenir\ Next.ttc 0 5195904) (Avenir\ Next.ttc 0 2838512)))
((Avenir\ Next Bold\ Italic) ((Avenir\ Next.ttc 1 5195904) (Avenir\ Next.ttc 1 2838512)))
((Avenir\ Next Condensed) ((Avenir\ Next\ Condensed.ttc 5 3157212) (Avenir\ Next\ Condensed.ttc 7 3157212) (Avenir\ Next\ Condensed.ttc 5 2794276) (Avenir\ Next\ Condensed.ttc 7 2794276)))
((Avenir\ Next Condensed\ Bold) ((Avenir\ Next\ Condensed.ttc 0 3157212) (Avenir\ Next\ Condensed.ttc 0 2794276)))
((Avenir\ Next Condensed\ Bold\ Italic) ((Avenir\ Next\ Condensed.ttc 1 3157212) (Avenir\ Next\ Condensed.ttc 1 2794276)))
((Avenir\ Next Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 4 3157212) (Avenir\ Next\ Condensed.ttc 6 3157212) (Avenir\ Next\ Condensed.ttc 4 2794276) (Avenir\ Next\ Condensed.ttc 6 2794276)))
((Avenir\ Next DemiBold) ((Avenir\ Next.ttc 2 5195904) (Avenir\ Next.ttc 2 2838512)))
((Avenir\ Next DemiBold\ Condensed) ((Avenir\ Next\ Condensed.ttc 2 3157212) (Avenir\ Next\ Condensed.ttc 2 2794276)))
((Avenir\ Next DemiBold\ Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 3 3157212) (Avenir\ Next\ Condensed.ttc 3 2794276)))
((Avenir\ Next DemiBold\ Italic) ((Avenir\ Next.ttc 3 5195904) (Avenir\ Next.ttc 3 2838512)))
((Avenir\ Next Heavy) ((Avenir\ Next.ttc 8 5195904) (Avenir\ Next.ttc 8 2838512)))
((Avenir\ Next Heavy\ Condensed) ((Avenir\ Next\ Condensed.ttc 8 3157212) (Avenir\ Next\ Condensed.ttc 8 2794276)))
((Avenir\ Next Heavy\ Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 9 3157212) (Avenir\ Next\ Condensed.ttc 9 2794276)))
((Avenir\ Next Heavy\ Italic) ((Avenir\ Next.ttc 9 5195904) (Avenir\ Next.ttc 9 2838512)))
((Avenir\ Next Italic) ((Avenir\ Next.ttc 4 5195904) (Avenir\ Next.ttc 6 5195904) (Avenir\ Next.ttc 4 2838512) (Avenir\ Next.ttc 6 2838512)))
((Avenir\ Next Regular) ((Avenir\ Next.ttc 5 5195904) (Avenir\ Next.ttc 7 5195904) (Avenir\ Next.ttc 5 2838512) (Avenir\ Next.ttc 7 2838512)))
((Avenir\ Next Thin) ((Avenir\ Next.ttc 10 5195904) (Avenir\ Next.ttc 10 2838512)))
((Avenir\ Next Thin\ Condensed) ((Avenir\ Next\ Condensed.ttc 10 3157212) (Avenir\ Next\ Condensed.ttc 10 2794276)))
((Avenir\ Next Thin\ Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 11 3157212) (Avenir\ Next\ Condensed.ttc 11 2794276)))
((Avenir\ Next Thin\ Italic) ((Avenir\ Next.ttc 11 5195904) (Avenir\ Next.ttc 11 2838512)))
((Avocado Regular) ((avocado_.ttf 0 67056)))
((Ayuthaya Regular) ((Ayuthaya.ttf 0 297876) (Ayuthaya.ttf 0 304592) (Ayuthaya.ttf 0 305352)))
((Baekmuk\ Gulim Regular) ((gulim.ttf 0 10385096)))
((Baghdad Regular) ((Baghdad.ttf 0 99132) (Baghdad.ttc 0 106220) (Baghdad.ttf 0 99492)))
((Baghdad\ PUA Regular) ((Baghdad.ttc 1 106220)))
((Balham Regular) ((Balham.otf 0 23908)))
((Bangla\ MN Bold) ((Bangla\ MN.ttc 1 830804) (Bangla\ MN.ttc 1 832052)))
((Bangla\ MN Regular) ((Bangla\ MN.ttc 0 830804) (Bangla\ MN.ttc 0 832052)))
((Bangla\ Sangam\ MN Bold) ((Bangla\ Sangam\ MN.ttc 1 762944) (Bangla\ Sangam\ MN.ttc 1 698648)))
((Bangla\ Sangam\ MN Regular) ((Bangla\ Sangam\ MN.ttc 0 762944) (Bangla\ Sangam\ MN.ttc 0 698648)))
((Baoli\ SC Regular) ((Baoli.ttc 0 8474944)))
((Baskerville Bold) ((Baskerville.ttc 1 449004) (Baskerville.ttc 0 1277484) (Baskerville.ttc 1 1123736)))
((Baskerville Bold\ Italic) ((Baskerville.ttc 4 449004) (Baskerville.ttc 1 1277484) (Baskerville.ttc 4 1123736)))
((Baskerville Italic) ((Baskerville.ttc 2 449004) (Baskerville.ttc 2 1277484) (Baskerville.ttc 2 1123736)))
((Baskerville Regular) ((Baskerville.ttc 0 449004) (Baskerville.ttc 3 1277484) (Baskerville.ttc 0 1123736)))
((Baskerville SemiBold) ((Baskerville.ttc 5 449004) (Baskerville.ttc 4 1277484) (Baskerville.ttc 5 1123736)))
((Baskerville SemiBold\ Italic) ((Baskerville.ttc 3 449004) (Baskerville.ttc 5 1277484) (Baskerville.ttc 3 1123736)))
((Batang Regular) ((batang.ttf 0 15519828)))
((BB\ Petie\ Boy Destroyed) ((BB_Petie_Boy_Destroyed.ttf 0 350196)))
((BB\ Petie\ Boy Heavy) ((BB_Petie_Boy_Heavy.ttf 0 199800)))
((BB\ Petie\ Boy Light) ((BB_Petie_Boy_Light.ttf 0 126260)))
((BB\ Petie\ Boy Medium) ((BB_Petie_Boy_Medium.ttf 0 375376)))
((Beirut Regular) ((Beirut.ttc 0 78976)))
((Beirut\ PUA Regular) ((Beirut.ttc 1 78976)))
((Beroga Regular) ((Beroga.ttf 0 91868)))
((BiauKai Regular) ((BiauKai.ttf 0 13911192)))
((Big\ Caslon Medium) ((BigCaslon.ttf 0 140976) (BigCaslon.ttf 0 213512)))
((Bimbo\ JVE Regular) ((Bimbo_JVE.ttf 0 18700)))
((Bitstream\ Vera\ Sans Bold) ((VeraBd.ttf 0 58716)))
((Bitstream\ Vera\ Sans Bold\ Oblique) ((VeraBI.ttf 0 63208)))
((Bitstream\ Vera\ Sans Oblique) ((VeraIt.ttf 0 63684)))
((Bitstream\ Vera\ Sans Roman) ((Vera.ttf 0 65932)))
((Bitstream\ Vera\ Sans\ Mono Bold) ((VeraMoBd.ttf 0 49052)))
((Bitstream\ Vera\ Sans\ Mono Bold\ Oblique) ((VeraMoBI.ttf 0 55032)))
((Bitstream\ Vera\ Sans\ Mono Oblique) ((VeraMoIt.ttf 0 54508)))
((Bitstream\ Vera\ Sans\ Mono Roman) ((VeraMono.ttf 0 49224)))
((Bitstream\ Vera\ Serif Bold) ((VeraSeBd.ttf 0 58736)))
((Bitstream\ Vera\ Serif Roman) ((VeraSe.ttf 0 60280)))
((BlackChancery Regular) ((BLKCHCRY.ttf 0 56732)))
((BloomingGrove Medium) ((bgrove.otf 0 32292) (bgrove.ttf 0 18744)))
((BloomingGroveAltBold Bold) ((bgrovealtb.otf 0 49912) (bgrovealtb.ttf 0 17648)))
((BloomingGroveAlternate Alternate) ((bgrovealt.otf 0 29944) (bgrovealt.ttf 0 18872)))
((BloomingGroveBold Bold) ((bgroveb.otf 0 54344) (bgroveb.ttf 0 17732)))
((Bodoni\ 72 Bold) ((Bodoni\ 72.ttc 2 416692)))
((Bodoni\ 72 Book) ((Bodoni\ 72.ttc 0 416692)))
((Bodoni\ 72 Book\ Italic) ((Bodoni\ 72.ttc 1 416692)))
((Bodoni\ 72\ Oldstyle Bold) ((Bodoni\ 72\ OS.ttc 2 230216)))
((Bodoni\ 72\ Oldstyle Book) ((Bodoni\ 72\ OS.ttc 0 230216)))
((Bodoni\ 72\ Oldstyle Book\ Italic) ((Bodoni\ 72\ OS.ttc 1 230216)))
((Bodoni\ 72\ Smallcaps Book) ((Bodoni\ 72\ Smallcaps\ Book.ttf 0 79956)))
((Bodoni\ Ornaments Regular) ((Bodoni\ Ornaments.ttf 0 72492)))
((BPreplay Bold) ((BPreplayBold.otf 0 31480)))
((BPreplay Bold\ Italic) ((BPreplayBoldItalics.otf 0 33204)))
((BPreplay Italic) ((BPreplayItalics.otf 0 33248)))
((BPreplay Regular) ((BPreplay.otf 0 30672)))
((Bradley\ Hand Bold) ((Bradley\ Hand\ Bold.ttf 0 592324)))
((Brewsky Regular) ((Brewsky.ttf 0 51836)))
((Brush\ Script\ MT Italic) ((Brush\ Script.ttf 0 56844) (Brush\ Script.ttf 0 222640)))
((Cake\ Frosting Decorative) ((CakeFrostingDecorative.ttf 0 297484)))
((Casa\ Sans Regular) ((casa_sans.ttf 0 50256)))
((Catenary\ Stamp Regular) ((Catenary-Stamp.ttf 0 455376)))
((Chalkboard Bold) ((Chalkboard.ttc 1 184212) (Chalkboard.ttc 1 166072)))
((Chalkboard Regular) ((Chalkboard.ttc 0 184212) (Chalkboard.ttc 0 166072)))
((Chalkboard\ SE Bold) ((ChalkboardSE.ttc 2 519772) (ChalkboardSE.ttc 2 558788)))
((Chalkboard\ SE Light) ((ChalkboardSE.ttc 0 519772) (ChalkboardSE.ttc 0 558788)))
((Chalkboard\ SE Regular) ((ChalkboardSE.ttc 1 519772) (ChalkboardSE.ttc 1 558788)))
((Chalkduster Regular) ((Chalkduster.ttf 0 499996) (Chalkduster.ttf 0 483652)))
((Charakterny Regular) ((Charakterny.otf 0 230200)))
((Charis\ SIL Bold) ((CharisSILB.ttf 0 1602332)))
((Charis\ SIL Bold\ Italic) ((CharisSILBI.ttf 0 1594156)))
((Charis\ SIL Italic) ((CharisSILI.ttf 0 1620428)))
((Charis\ SIL Regular) ((CharisSILR.ttf 0 1654136)))
((Charter Black) ((Charter.ttc 5 2097188)))
((Charter Black\ Italic) ((Charter.ttc 4 2097188)))
((Charter Bold) ((Charter.ttc 3 2097188)))
((Charter Bold\ Italic) ((Charter.ttc 2 2097188)))
((Charter Italic) ((Charter.ttc 1 2097188)))
((Charter Roman) ((Charter.ttc 0 2097188)))
((Chartrand Medium) ((Chartrand.otf 0 14732)))
((Chronicles\ of\ Arkmar Regular) ((Chronicles_of_ArkMar.ttf 0 145356)))
((CMU\ Bright Bold) ((cmunbbx.otf 0 219276)))
((CMU\ Bright BoldOblique) ((cmunbxo.otf 0 223376)))
((CMU\ Bright Oblique) ((cmunbmo.otf 0 218240)))
((CMU\ Bright Roman) ((cmunbmr.otf 0 241008)))
((CMU\ Bright SemiBold) ((cmunbsr.otf 0 212804)))
((CMU\ Bright SemiBoldOblique) ((cmunbso.otf 0 217292)))
((CMU\ Classical\ Serif Italic) ((cmunci.otf 0 248868)))
((CMU\ Concrete Bold) ((cmunobx.otf 0 254872)))
((CMU\ Concrete BoldItalic) ((cmunobi.otf 0 243956)))
((CMU\ Concrete Italic) ((cmunoti.otf 0 238356)))
((CMU\ Concrete Roman) ((cmunorm.otf 0 280304)))
((CMU\ Sans\ Serif Bold) ((cmunsx.otf 0 274384)))
((CMU\ Sans\ Serif BoldOblique) ((cmunso.otf 0 237356)))
((CMU\ Sans\ Serif DemiCondensed) ((cmunssdc.otf 0 220148)))
((CMU\ Sans\ Serif Medium) ((cmunss.otf 0 222060)))
((CMU\ Sans\ Serif Oblique) ((cmunsi.otf 0 222660)))
((CMU\ Serif Bold) ((cmunbx.otf 0 319676)))
((CMU\ Serif BoldItalic) ((cmunbi.otf 0 251884)))
((CMU\ Serif Italic) ((cmunti.otf 0 248088)))
((CMU\ Serif Roman) ((cmunrm.otf 0 330492)))
((CMU\ Serif\ Extra BoldNonextended) ((cmunrb.otf 0 226856)))
((CMU\ Serif\ Extra BoldSlanted) ((cmunbl.otf 0 320560)))
((CMU\ Serif\ Extra RomanSlanted) ((cmunsl.otf 0 320152)))
((CMU\ Serif\ Upright\ Italic UprightItalic) ((cmunui.otf 0 227084)))
((CMU\ Typewriter\ Text Bold) ((cmuntb.otf 0 198108)))
((CMU\ Typewriter\ Text BoldItalic) ((cmuntx.otf 0 207728)))
((CMU\ Typewriter\ Text Italic) ((cmunit.otf 0 195444)))
((CMU\ Typewriter\ Text Light) ((cmunbtl.otf 0 188976)))
((CMU\ Typewriter\ Text LightOblique) ((cmunbto.otf 0 196448)))
((CMU\ Typewriter\ Text Oblique) ((cmunst.otf 0 244900)))
((CMU\ Typewriter\ Text Regular) ((cmuntt.otf 0 301664)))
((CMU\ Typewriter\ Text\ Variable\ Width Italic) ((cmunvi.otf 0 195716)))
((CMU\ Typewriter\ Text\ Variable\ Width Medium) ((cmunvt.otf 0 186996)))
((Cochin Bold) ((Cochin.ttc 1 886724) (Cochin.ttc 1 1224236) (Cochin.ttc 1 1222088)))
((Cochin Bold\ Italic) ((Cochin.ttc 3 886724) (Cochin.ttc 3 1224236) (Cochin.ttc 3 1222088)))
((Cochin Italic) ((Cochin.ttc 2 886724) (Cochin.ttc 2 1224236) (Cochin.ttc 2 1222088)))
((Cochin Regular) ((Cochin.ttc 0 886724) (Cochin.ttc 0 1224236) (Cochin.ttc 0 1222088)))
((Comfortaa Bold) ((Comfortaa-Bold.ttf 0 176924) (Comfortaa-Bold.ttf 0 170432)))
((Comfortaa Light) ((Comfortaa-Light.ttf 0 172812) (Comfortaa-Light.ttf 0 170140)))
((Comfortaa Regular) ((Comfortaa-Regular.ttf 0 169476) (Comfortaa-Regular.ttf 0 170716)))
((Comic\ Sans\ MS Bold) ((Comic\ Sans\ MS\ Bold.ttf 0 120120) (comicbd.ttf 0 111476)))
((Comic\ Sans\ MS Regular) ((Comic\ Sans\ MS.ttf 0 135484) (comic.ttf 0 127596)))
((Constanze Regular) ((ConstanzeInitials.otf 0 8432)))
((Copperplate Bold) ((Copperplate.ttc 2 231116) (Copperplate.ttc 2 1257000) (Copperplate.ttc 2 331884)))
((Copperplate Light) ((Copperplate.ttc 1 231116) (Copperplate.ttc 1 1257000) (Copperplate.ttc 1 331884)))
((Copperplate Regular) ((Copperplate.ttc 0 231116) (Copperplate.ttc 0 1257000) (Copperplate.ttc 0 331884)))
((Corsiva\ Hebrew Bold) ((CorsivaBold.ttf 0 42096) (Corsiva.ttc 1 71784)))
((Corsiva\ Hebrew Regular) ((Corsiva.ttf 0 40340) (Corsiva.ttc 0 71784)))
((Courier\ New Bold) ((Courier\ New\ Bold.ttf 0 691796) (courbd.ttf 0 312920)))
((Courier\ New Bold\ Italic) ((Courier\ New\ Bold\ Italic.ttf 0 506640) (courbi.ttf 0 236148)))
((Courier\ New Italic) ((Courier\ New\ Italic.ttf 0 589900) (couri.ttf 0 245032)))
((Courier\ New Regular) ((Courier\ New.ttf 0 684624) (cour.ttf 0 303296)))
((Cuprum Bold) ((Cuprum-Bold.ttf 0 100172)))
((Cuprum Bold\ Italic) ((Cuprum-BoldItalic.ttf 0 96188)))
((Cuprum Italic) ((Cuprum-Italic.ttf 0 96400)))
((Cuprum Regular) ((Cuprum-Regular.ttf 0 100608)))
((Cyen Regular) ((Cyen.ttf 0 9580)))
((Damascus Bold) ((Damascus.ttc 6 1973380) (Damascus.ttc 1 516276)))
((Damascus Light) ((Damascus.ttc 2 1973380)))
((Damascus Medium) ((Damascus.ttc 4 1973380)))
((Damascus Regular) ((Damascus.ttc 0 1973380) (Damascus.ttc 0 516276)))
((Damascus Semi\ Bold) ((Damascus.ttc 8 1973380)))
((Damascus\ PUA Bold) ((Damascus.ttc 7 1973380)))
((Damascus\ PUA Light) ((Damascus.ttc 3 1973380)))
((Damascus\ PUA Medium) ((Damascus.ttc 5 1973380)))
((Damascus\ PUA Regular) ((Damascus.ttc 1 1973380)))
((Damascus\ PUA Semi\ Bold) ((Damascus.ttc 9 1973380)))
((Dark\ Garden Regular) ((DarkGardenMK.ttf 0 62236)))
((DecoType\ Naskh Regular) ((DecoTypeNaskh.ttf 0 67608) (DecoTypeNaskh.ttc 0 94656) (DecoTypeNaskh.ttf 0 67956)))
((DecoType\ Naskh\ PUA Regular) ((DecoTypeNaskh.ttc 1 94656)))
((DejaVu\ Sans Bold) ((DejaVuSans-Bold.ttf 0 584396) (DejaVuSans-Bold.ttf 0 672300)))
((DejaVu\ Sans Bold\ Condensed) ((DejaVuSansCondensed-Bold.ttf 0 545712)))
((DejaVu\ Sans Bold\ Condensed\ Oblique) ((DejaVuSansCondensed-BoldOblique.ttf 0 493756)))
((DejaVu\ Sans Bold\ Oblique) ((DejaVuSans-BoldOblique.ttf 0 524624) (DejaVuSans-BoldOblique.ttf 0 611212)))
((DejaVu\ Sans Book) ((DejaVuSans.ttf 0 633604) (DejaVuSans.ttf 0 720012)))
((DejaVu\ Sans Condensed\ Bold) ((DejaVuSansCondensed-Bold.ttf 0 545712) (DejaVuSansCondensed-Bold.ttf 0 631992)))
((DejaVu\ Sans Condensed\ Bold\ Oblique) ((DejaVuSansCondensed-BoldOblique.ttf 0 493756) (DejaVuSansCondensed-BoldOblique.ttf 0 580168)))
((DejaVu\ Sans Condensed\ Book) ((DejaVuSansCondensed.ttf 0 555944) (DejaVuSansCondensed.ttf 0 643852)))
((DejaVu\ Sans Condensed\ Oblique) ((DejaVuSansCondensed-Oblique.ttf 0 489032) (DejaVuSansCondensed-Oblique.ttf 0 576004)))
((DejaVu\ Sans ExtraLight) ((DejaVuSans-ExtraLight.ttf 0 329444)))
((DejaVu\ Sans Light\ ExtraLight) ((DejaVuSans-ExtraLight.ttf 0 329444) (DejaVuSans-ExtraLight.ttf 0 345208)))
((DejaVu\ Sans Oblique) ((DejaVuSans-Oblique.ttf 0 524396) (DejaVuSans-Oblique.ttf 0 611556)))
((DejaVu\ Sans\ Mono Bold) ((DejaVuSansMono-Bold.ttf 0 302868) (DejaVuSansMono-Bold.ttf 0 313856)))
((DejaVu\ Sans\ Mono Bold\ Oblique) ((DejaVuSansMono-BoldOblique.ttf 0 224160) (DejaVuSansMono-BoldOblique.ttf 0 235848)))
((DejaVu\ Sans\ Mono Book) ((DejaVuSansMono.ttf 0 322524) (DejaVuSansMono.ttf 0 333636)))
((DejaVu\ Sans\ Mono Oblique) ((DejaVuSansMono-Oblique.ttf 0 230244) (DejaVuSansMono-Oblique.ttf 0 241972)))
((DejaVu\ Serif Bold) ((DejaVuSerif-Bold.ttf 0 307596) (DejaVuSerif-Bold.ttf 0 341072)))
((DejaVu\ Serif Bold\ Condensed) ((DejaVuSerifCondensed-Bold.ttf 0 283140)))
((DejaVu\ Serif Bold\ Condensed\ Italic) ((DejaVuSerifCondensed-BoldItalic.ttf 0 294584)))
((DejaVu\ Serif Bold\ Italic) ((DejaVuSerif-BoldItalic.ttf 0 295360) (DejaVuSerif-BoldItalic.ttf 0 332036)))
((DejaVu\ Serif Book) ((DejaVuSerif.ttf 0 330052) (DejaVuSerif.ttf 0 363200)))
((DejaVu\ Serif Condensed\ Bold) ((DejaVuSerifCondensed-Bold.ttf 0 283140) (DejaVuSerifCondensed-Bold.ttf 0 316440)))
((DejaVu\ Serif Condensed\ Bold\ Italic) ((DejaVuSerifCondensed-BoldItalic.ttf 0 294584) (DejaVuSerifCondensed-BoldItalic.ttf 0 331128)))
((DejaVu\ Serif Condensed\ Book) ((DejaVuSerifCondensed.ttf 0 296976) (DejaVuSerifCondensed.ttf 0 330012)))
((DejaVu\ Serif Condensed\ Italic) ((DejaVuSerifCondensed-Italic.ttf 0 302444) (DejaVuSerifCondensed-Italic.ttf 0 338140)))
((DejaVu\ Serif Italic) ((DejaVuSerif-Italic.ttf 0 303004) (DejaVuSerif-Italic.ttf 0 338776)))
((Delius Regular) ((Delius-Regular.ttf 0 77488)))
((Delius\ Swash\ Caps Regular) ((DeliusSwashCaps-Regular.ttf 0 63052)))
((Delius\ Unicase Bold) ((DeliusUnicase-Bold.ttf 0 36120)))
((Delius\ Unicase Regular) ((DeliusUnicase-Regular.ttf 0 32904)))
((Denise Regular) ((Denise_Handwriting.ttf 0 49788)))
((Designer\ Notes Bold) ((Designer-Notes-Bold.ttf 0 49748)))
((Designer\ Notes Regular) ((Designer-Notes.ttf 0 62808)))
((Devanagari\ MT Bold) ((DevanagariMTBold.ttf 0 315620) (DevanagariMT.ttc 1 406212)))
((Devanagari\ MT Regular) ((DevanagariMT.ttf 0 332324) (DevanagariMT.ttc 0 406212)))
((Devanagari\ Sangam\ MN Bold) ((Devanagari\ Sangam\ MN.ttc 1 695000) (Devanagari\ Sangam\ MN.ttc 1 672836)))
((Devanagari\ Sangam\ MN Regular) ((Devanagari\ Sangam\ MN.ttc 0 695000) (Devanagari\ Sangam\ MN.ttc 0 672836)))
((Didot Bold) ((Didot.ttc 2 352960) (Didot.ttc 2 712936) (Didot.ttc 2 352996)))
((Didot Italic) ((Didot.ttc 1 352960) (Didot.ttc 1 712936) (Didot.ttc 1 352996)))
((Didot Regular) ((Didot.ttc 0 352960) (Didot.ttc 0 712936) (Didot.ttc 0 352996)))
((Din Condensed\ Bold) ((DIN\ Condensed\ Bold.ttf 0 82260)))
((DIN\ Alternate Bold) ((DIN\ Alternate\ Bold.ttf 0 147024)))
((Dinosaur\ Skin Regular) ((Dinosaur\ Skin.ttf 0 101328)))
((Diwan\ Kufi Regular) ((Diwan\ Kufi.ttc 0 90540)))
((Diwan\ Kufi\ PUA Regular) ((Diwan\ Kufi.ttc 1 90540)))
((Diwan\ Thuluth Regular) ((Diwan\ Thuluth.ttf 0 1318280)))
((Doris\ PP bold) ((DORISBR.ttf 0 33980)))
((Double\ Strike Regular) ((Double\ Strike.ttf 0 60156) (DoubleStrike.otf 0 27864)))
((Doulos\ SIL Regular) ((DoulosSILR.ttf 0 1721928)))
((Droid\ Sans Bold) ((DroidSans-Bold.ttf 0 194488) (DroidSans-Bold.ttf 0 191032)))
((Droid\ Sans Regular) ((DroidSans.ttf 0 190776) (DroidSans.ttf 0 190044)))
((Droid\ Sans\ Mono Regular) ((DroidSansMono.ttf 0 119380) (DroidSansMono.ttf 0 117072)))
((Droid\ Serif Bold) ((DroidSerif-Bold.ttf 0 185228) (DroidSerif-Bold.ttf 0 184836)))
((Droid\ Serif Bold\ Italic) ((DroidSerif-BoldItalic.ttf 0 190304) (DroidSerif-BoldItalic.ttf 0 189916)))
((Droid\ Serif Italic) ((DroidSerif-Italic.ttf 0 177560) (DroidSerif-Italic.ttf 0 177176)))
((Droid\ Serif Regular) ((DroidSerif-Regular.ttf 0 172916) (DroidSerif-Regular.ttf 0 172532)))
((DuCahier\ xp Regular) ((TASSELXP.ttf 0 75512)))
((Dufay Normal) ((Dufay.ttf 0 44528)))
((Dustismo \ Bold) ((dustismo_bold.ttf 0 53168)))
((Dustismo \ Bold\ Italic) ((dustismo_bold_italic.ttf 0 62716)))
((Dustismo \ Italic) ((dustismo_italic.ttf 0 60948)))
((Dustismo Regular) ((Dustismo.ttf 0 52352)))
((Dustismo\ Roman Bold) ((Dustismo_Roman_Bold.ttf 0 61560)))
((Dustismo\ Roman Bold\ Italic) ((Dustismo_Roman_Italic_Bold.ttf 0 65524)))
((Dustismo\ Roman Italic) ((Dustismo_Roman_Italic.ttf 0 83048)))
((Dustismo\ Roman Regular) ((Dustismo_Roman.ttf 0 105340)))
((EB\ Garamond\ 12 Italic) ((EBGaramond12-Italic.ttf 0 508748)))
((EB\ Garamond\ 12 Regular) ((EBGaramond12-Regular.ttf 0 625440)))
((EB\ Garamond\ Initials Regular) ((EBGaramond-Initials.ttf 0 245764)))
((Elvifrance Regular) ((elvifrance.ttf 0 29928)))
((Essays1743 Bold) ((Essays1743-Bold.ttf 0 99788)))
((Essays1743 BoldItalic) ((Essays1743-BoldItalic.ttf 0 105300)))
((Essays1743 Italic) ((Essays1743-Italic.ttf 0 105124)))
((Essays1743 Medium) ((Essays1743.ttf 0 100660)))
((Estrangelo\ Edessa Regular) ((estre.ttf 0 79744)))
((Euphemia\ UCAS Bold) ((EuphemiaCASBold.ttf 0 175864) (EuphemiaCAS.ttc 1 550984) (EuphemiaCAS.ttc 1 547808)))
((Euphemia\ UCAS Italic) ((EuphemiaCASItalic.ttf 0 191116) (EuphemiaCAS.ttc 2 550984) (EuphemiaCAS.ttc 2 547808)))
((Euphemia\ UCAS Regular) ((EuphemiaCASRegular.ttf 0 212724) (EuphemiaCAS.ttc 0 550984) (EuphemiaCAS.ttc 0 547808)))
((EvilClown Regular) ((EVILCLOW.ttf 0 23244)))
((FandolFang Regular) ((FandolFang-Regular.otf 0 6148948)))
((FandolHei Bold) ((FandolHei-Bold.otf 0 3910356)))
((FandolHei Regular) ((FandolHei-Regular.otf 0 5102424)))
((FandolKai Regular) ((FandolKai-Regular.otf 0 6583228)))
((FandolSong Bold) ((FandolSong-Bold.otf 0 5194124)))
((FandolSong Regular) ((FandolSong-Regular.otf 0 3973332)))
((FangSong_GB2312 Regular) ((simfang.ttf 0 3996872)))
((Farah Regular) ((Farah.ttc 0 88452)))
((Farah\ PUA Regular) ((Farah.ttc 1 88452)))
((Farisi Regular) ((Farisi.ttf 0 279940)))
((Fava Black) ((Fava-black.ttf 0 119888)))
((Foglihten Regular) ((Foglihten-068.otf 0 390372)))
((FoglihtenBlackPcs BlackPcs) ((FoglihtenBlackPcs.otf 0 294832)))
((FoglihtenBPS01 Regular) ((FogBPS01.otf 0 18556)))
((FoglihtenFr01 Regular) ((FoglihtenFr01.otf 0 81340)))
((FoglihtenFr02 Regular) ((FoglihtenFr02.otf 0 100288)))
((FoglihtenNo01 Regular) ((FoglihtenNo01.otf 0 220820)))
((FoglihtenNo03 Regular) ((FoglihtenNo03.otf 0 219980)))
((FoglihtenNo04 Regular) ((FoglihtenNo04-070.otf 0 372592)))
((FoglihtenNo06 Regular) ((FoglihtenNo06.otf 0 343752)))
((FoglihtenPCS Petitecaps) ((FoglihtenPCS-068.otf 0 194132)))
((Franklin\ Gothic Italic) ((framdit.ttf 0 152844)))
((Franklin\ Gothic Regular) ((framd.ttf 0 135984)))
((FreeMono Bold) ((FreeMonoBold.ttf 0 165028) (FreeMonoBold.ttf 0 296284) (FreeMonoBold.ttf 0 173608)))
((FreeMono Bold\ Oblique) ((FreeMonoBoldOblique.ttf 0 295360)))
((FreeMono BoldOblique) ((FreeMonoBoldOblique.ttf 0 145836) (FreeMonoBoldOblique.ttf 0 169936)))
((FreeMono Medium) ((FreeMono.ttf 0 314936) (FreeMono.ttf 0 343980)))
((FreeMono Oblique) ((FreeMonoOblique.ttf 0 197400) (FreeMonoOblique.ttf 0 390692) (FreeMonoOblique.ttf 0 208128)))
((FreeMono Regular) ((FreeMono.ttf 0 584424)))
((FreeSans Bold) ((FreeSansBold.ttf 0 172584) (FreeSansBold.ttf 0 416128) (FreeSansBold.ttf 0 359272)))
((FreeSans Bold\ Oblique) ((FreeSansBoldOblique.ttf 0 342488)))
((FreeSans BoldOblique) ((FreeSansBoldOblique.ttf 0 159048) (FreeSansBoldOblique.ttf 0 301188)))
((FreeSans Medium) ((FreeSans.ttf 0 460384) (FreeSans.ttf 0 714456)))
((FreeSans Oblique) ((FreeSansOblique.ttf 0 301100) (FreeSansOblique.ttf 0 763696) (FreeSansOblique.ttf 0 441432)))
((FreeSans Regular) ((FreeSans.ttf 0 1563256)))
((FreeSerif Bold) ((FreeSerifBold.ttf 0 268612) (FreeSerifBold.ttf 0 1310828) (FreeSerifBold.ttf 0 615292)))
((FreeSerif Bold\ Italic) ((FreeSerifBoldItalic.ttf 0 608708)))
((FreeSerif BoldItalic) ((FreeSerifBoldItalic.ttf 0 241576) (FreeSerifBoldItalic.ttf 0 508412)))
((FreeSerif Italic) ((FreeSerifItalic.ttf 0 410068) (FreeSerifItalic.ttf 0 922088) (FreeSerifItalic.ttf 0 691448)))
((FreeSerif Medium) ((FreeSerif.ttf 0 1288080) (FreeSerif.ttf 0 1687516)))
((FreeSerif Regular) ((FreeSerif.ttf 0 3303588)))
((Futura Condensed\ ExtraBold) ((Futura.ttc 3 321740) (Futura.ttc 3 288740) (Futura.ttc 3 315748)))
((Futura Condensed\ Medium) ((Futura.ttc 2 321740) (Futura.ttc 2 288740) (Futura.ttc 2 315748)))
((Futura Medium) ((Futura.ttc 0 321740) (Futura.ttc 0 288740) (Futura.ttc 0 315748)))
((Futura Medium\ Italic) ((Futura.ttc 1 321740) (Futura.ttc 1 288740) (Futura.ttc 1 315748)))
((Galberik Regular) ((Galberik.otf 0 198496)))
((Gargi Medium) ((gargi.ttf 0 72500)))
((Garineldo Regular) ((Garineldo.otf 0 362280)))
((GarineldoNo01 Regular) ((GarineldoNo01.otf 0 387028)))
((GarineldoNo02 Regular) ((GarineldoNo02.otf 0 430552)))
((Garuda Bold) ((Garuda-Bold.ttf 0 76136)))
((Garuda BoldOblique) ((Garuda-BoldOblique.ttf 0 87180)))
((Garuda Book) ((Garuda.ttf 0 74876)))
((Garuda Oblique) ((Garuda-Oblique.ttf 0 87788)))
((Gatometrix Regular) ((Gatometrix.otf 0 191900)))
((Gautami Regular) ((gautami.ttf 0 214936)))
((Gears\ of\ Peace Regular) ((GearsOfPeace.ttf 0 19628)))
((Geeza\ Pro Bold) ((Geeza\ Pro\ Bold.ttf 0 169244) (GeezaPro.ttc 1 994932) (Geeza\ Pro\ Bold.ttf 0 272984)))
((Geeza\ Pro Regular) ((Geeza\ Pro.ttf 0 168796) (GeezaPro.ttc 0 994932) (Geeza\ Pro.ttf 0 271732)))
((Geeza\ Pro\ Interface Bold) ((GeezaPro.ttc 3 994932)))
((Geeza\ Pro\ Interface Light) ((GeezaPro.ttc 4 994932)))
((Geeza\ Pro\ Interface Regular) ((GeezaPro.ttc 2 994932)))
((Geeza\ PUA Bold) ((GeezaPro.ttc 6 994932)))
((Geeza\ PUA Regular) ((GeezaPro.ttc 5 994932)))
((Gentium Italic) ((GenI102.ttf 0 314476)))
((Gentium Regular) ((GenR102.ttf 0 362664)))
((Gentium\ Basic Bold) ((GenBasB.ttf 0 271648)))
((Gentium\ Basic Bold\ Italic) ((GenBasBI.ttf 0 250668)))
((Gentium\ Basic Italic) ((GenBasI.ttf 0 263504)))
((Gentium\ Basic Regular) ((GenBasR.ttf 0 269048)))
((Gentium\ Book\ Basic Bold) ((GenBkBasB.ttf 0 271832)))
((Gentium\ Book\ Basic Bold\ Italic) ((GenBkBasBI.ttf 0 249924)))
((Gentium\ Book\ Basic Italic) ((GenBkBasI.ttf 0 266156)))
((Gentium\ Book\ Basic Regular) ((GenBkBasR.ttf 0 272460)))
((GentiumAlt Italic) ((GenAI102.ttf 0 315860)))
((GentiumAlt Regular) ((GenAR102.ttf 0 364056)))
((Georgia Bold) ((Georgia\ Bold.ttf 0 148768) (georgiab.ttf 0 141032) (Georgia\ Bold.ttf 0 363800)))
((Georgia Bold\ Italic) ((Georgia\ Bold\ Italic.ttf 0 167476) (georgiaz.ttf 0 159736) (Georgia\ Bold\ Italic.ttf 0 385768)))
((Georgia Italic) ((Georgia\ Italic.ttf 0 165208) (georgiai.ttf 0 157388) (Georgia\ Italic.ttf 0 400624)))
((Georgia Regular) ((Georgia.ttf 0 159656) (georgia.ttf 0 155068) (Georgia.ttf 0 379588)))
((Gill\ Sans Bold) ((GillSans.ttc 1 589392) (GillSans.ttc 1 1220852) (GillSans.ttc 1 603640)))
((Gill\ Sans Bold\ Italic) ((GillSans.ttc 2 589392) (GillSans.ttc 3 1220852) (GillSans.ttc 2 603640)))
((Gill\ Sans Italic) ((GillSans.ttc 3 589392) (GillSans.ttc 2 1220852) (GillSans.ttc 3 603640)))
((Gill\ Sans Light) ((GillSans.ttc 4 589392) (GillSans.ttc 7 1220852) (GillSans.ttc 4 603640)))
((Gill\ Sans Light\ Italic) ((GillSans.ttc 5 589392) (GillSans.ttc 8 1220852) (GillSans.ttc 5 603640)))
((Gill\ Sans Regular) ((GillSans.ttc 0 589392) (GillSans.ttc 0 1220852) (GillSans.ttc 0 603640)))
((Gill\ Sans SemiBold) ((GillSans.ttc 4 1220852)))
((Gill\ Sans SemiBold\ Italic) ((GillSans.ttc 5 1220852)))
((Gill\ Sans UltraBold) ((GillSans.ttc 6 1220852)))
((Gotika Regular) ((Gotika.ttf 0 55868)))
((Gotika\ Apvalus Regular) ((Gotika\ Apvalus.ttf 0 55920)))
((Gotika\ Brokas Regular) ((Gotika\ Brokas.ttf 0 55136)))
((Gotika\ Serifai\ A Regular) ((Gotika\ Serifai\ A.ttf 0 36392)))
((Gotika\ Serifai\ B Regular) ((Gotika\ Serifai\ B.ttf 0 36748)))
((Goudy\ Bookletter\ 1911 Regular) ((GoudyBookletter1911.otf 0 39988)))
((Grunge\ Handwriting Regular) ((Grunge\ Handwriting.ttf 0 651948) (GrungeHandwriting.otf 0 368408)))
((Gujarati\ MT Bold) ((GujaratiMTBold.ttf 0 213708) (GujaratiMT.ttc 1 381112)))
((Gujarati\ MT Regular) ((GujaratiMT.ttf 0 224940) (GujaratiMT.ttc 0 381112)))
((Gujarati\ Sangam\ MN Bold) ((Gujarati\ Sangam\ MN.ttc 1 222348) (Gujarati\ Sangam\ MN.ttc 1 439680)))
((Gujarati\ Sangam\ MN Regular) ((Gujarati\ Sangam\ MN.ttc 0 222348) (Gujarati\ Sangam\ MN.ttc 0 439680)))
((Gurmukhi\ MN Bold) ((Gurmukhi\ MN.ttc 1 87380) (Gurmukhi\ MN.ttc 1 185648)))
((Gurmukhi\ MN Regular) ((Gurmukhi\ MN.ttc 0 87380) (Gurmukhi\ MN.ttc 0 185648)))
((Gurmukhi\ MT Regular) ((Gurmukhi.ttf 0 64572) (Gurmukhi.ttf 0 63936)))
((Gurmukhi\ Sangam\ MN Bold) ((Gurmukhi\ Sangam\ MN.ttc 1 168080) (Gurmukhi\ Sangam\ MN.ttc 1 166960)))
((Gurmukhi\ Sangam\ MN Regular) ((Gurmukhi\ Sangam\ MN.ttc 0 168080) (Gurmukhi\ Sangam\ MN.ttc 0 166960)))
((Hairline\ Quadrata Medium) ((Hairline\ Quadrata.ttf 0 24064)))
((Hand\ Drawn\ Shapes Regular) ((Hand\ Drawn\ Shapes.ttf 0 69924) (HandDrawnShapes.otf 0 26284)))
((Handserif Medium) ((HanSrf.ttf 0 86184)))
((Hannotate\ SC Bold) ((Hannotate.ttc 2 85383868)))
((Hannotate\ SC Regular) ((Hannotate.ttc 0 85383868)))
((Hannotate\ TC Bold) ((Hannotate.ttc 3 85383868)))
((Hannotate\ TC Regular) ((Hannotate.ttc 1 85383868)))
((HanziPen\ SC Bold) ((Hanzipen.ttc 2 71898356)))
((HanziPen\ SC Regular) ((Hanzipen.ttc 0 71898356)))
((HanziPen\ TC Bold) ((Hanzipen.ttc 3 71898356)))
((HanziPen\ TC Regular) ((Hanzipen.ttc 1 71898356)))
((HeadLineA Regular) ((HeadlineA.ttf 0 1215336) (HeadlineA.ttf 0 1198040)))
((Hei Regular) ((Hei.ttf 0 7502752)))
((Heiti\ SC Light) ((STHeiti\ Light.ttc 1 55331264) (STHeiti\ Light.ttc 1 55984748) (STHeiti\ Light.ttc 1 54382472) (STHeiti\ Light.ttc 1 56105488)))
((Heiti\ SC Medium) ((STHeiti\ Medium.ttc 1 55380344) (STHeiti\ Medium.ttc 1 55954340) (STHeiti\ Medium.ttc 1 54257344) (STHeiti\ Medium.ttc 1 55947944)))
((Heiti\ TC Light) ((STHeiti\ Light.ttc 0 55331264) (STHeiti\ Light.ttc 0 55984748) (STHeiti\ Light.ttc 0 54382472) (STHeiti\ Light.ttc 0 56105488)))
((Heiti\ TC Medium) ((STHeiti\ Medium.ttc 0 55380344) (STHeiti\ Medium.ttc 0 55954340) (STHeiti\ Medium.ttc 0 54257344) (STHeiti\ Medium.ttc 0 55947944)))
((HeitiUI\ GB18030PUA Thin) ((STHeiti\ Thin.ttc 2 8081556)))
((HeitiUI\ GB18030PUA Ultra\ Light) ((STHeiti\ UltraLight.ttc 2 8391392)))
((HeitiUI\ J Thin) ((STHeiti\ Thin.ttc 4 8081556)))
((HeitiUI\ J Ultra\ Light) ((STHeiti\ UltraLight.ttc 4 8391392)))
((HeitiUI\ K Thin) ((STHeiti\ Thin.ttc 3 8081556)))
((HeitiUI\ K Ultra\ Light) ((STHeiti\ UltraLight.ttc 3 8391392)))
((HeitiUI\ SC Thin) ((STHeiti\ Thin.ttc 1 8081556)))
((HeitiUI\ SC Ultra\ Light) ((STHeiti\ UltraLight.ttc 1 8391392)))
((HeitiUI\ TC Thin) ((STHeiti\ Thin.ttc 0 8081556)))
((HeitiUI\ TC Ultra\ Light) ((STHeiti\ UltraLight.ttc 0 8391392)))
((Helvetica Light) ((HelveticaLight.ttf 0 55756)))
((Helvetica Light\ Oblique) ((HelveticaLightItalic.ttf 0 50972)))
((Helvetica\ Neue Bold) ((HelveticaNeue.ttc 1 1395352)))
((Helvetica\ Neue Bold\ Italic) ((HelveticaNeue.ttc 3 1395352)))
((Helvetica\ Neue Condensed\ Black) ((HelveticaNeue.ttc 8 1395352)))
((Helvetica\ Neue Condensed\ Bold) ((HelveticaNeue.ttc 9 1395352)))
((Helvetica\ Neue Italic) ((HelveticaNeue.ttc 2 1395352)))
((Helvetica\ Neue Light) ((HelveticaNeue.ttc 4 1395352)))
((Helvetica\ Neue Light\ Italic) ((HelveticaNeue.ttc 5 1395352)))
((Helvetica\ Neue Medium) ((HelveticaNeue.ttc 10 1395352)))
((Helvetica\ Neue Regular) ((HelveticaNeue.ttc 0 1395352)))
((Helvetica\ Neue UltraLight) ((HelveticaNeue.ttc 6 1395352)))
((Helvetica\ Neue UltraLight\ Italic) ((HelveticaNeue.ttc 7 1395352)))
((Helvetica\ Neue\ DeskInterface Bold) ((HelveticaNeueDeskUI.ttc 2 2877688) (HelveticaNeueDeskInterface.ttc 1 5372956)))
((Helvetica\ Neue\ DeskInterface Bold\ Italic) ((HelveticaNeueDeskUI.ttc 3 2877688) (HelveticaNeueDeskUI.ttc 3 2877688)(HelveticaNeueDeskInterface.ttc 3 5372956)))
((Helvetica\ Neue\ DeskInterface Heavy) ((HelveticaNeueDeskInterface.ttc 9 5372956)))
((Helvetica\ Neue\ DeskInterface Italic) ((HelveticaNeueDeskUI.ttc 1 2877688) (HelveticaNeueDeskInterface.ttc 2 5372956)))
((Helvetica\ Neue\ DeskInterface Light) ((HelveticaNeueDeskInterface.ttc 6 5372956)))
((Helvetica\ Neue\ DeskInterface Medium) ((HelveticaNeueDeskInterface.ttc 4 5372956)))
((Helvetica\ Neue\ DeskInterface Medium\ Italic) ((HelveticaNeueDeskInterface.ttc 5 5372956)))
((Helvetica\ Neue\ DeskInterface Regular) ((HelveticaNeueDeskUI.ttc 0 2877688) (HelveticaNeueDeskInterface.ttc 0 5372956)))
((Helvetica\ Neue\ DeskInterface Thin) ((HelveticaNeueDeskInterface.ttc 7 5372956)))
((Helvetica\ Neue\ DeskInterface UltraLight) ((HelveticaNeueDeskInterface.ttc 8 5372956)))
((Herculanum Regular) ((Herculanum.ttf 0 106264)))
((Hiragino\ Kaku\ Gothic\ Interface W0) ((ヒラギノ角ゴシック\ W0.ttc 1 3567792)))
((Hiragino\ Kaku\ Gothic\ Interface W1) ((ヒラギノ角ゴシック\ W1.ttc 1 7286744)))
((Hiragino\ Kaku\ Gothic\ Interface W2) ((ヒラギノ角ゴシック\ W2.ttc 1 7270552)))
((Hiragino\ Kaku\ Gothic\ Interface W3) ((ヒラギノ角ゴシック\ W3.ttc 1 7891480)))
((Hiragino\ Kaku\ Gothic\ Interface W4) ((ヒラギノ角ゴシック\ W4.ttc 1 7259328)))
((Hiragino\ Kaku\ Gothic\ Interface W5) ((ヒラギノ角ゴシック\ W5.ttc 1 7260984)))
((Hiragino\ Kaku\ Gothic\ Interface W6) ((ヒラギノ角ゴシック\ W6.ttc 1 7998200)))
((Hiragino\ Kaku\ Gothic\ Interface W7) ((ヒラギノ角ゴシック\ W7.ttc 1 3607768)))
((Hiragino\ Kaku\ Gothic\ Interface W8) ((ヒラギノ角ゴシック\ W8.ttc 1 4096288)))
((Hiragino\ Kaku\ Gothic\ Interface W9) ((ヒラギノ角ゴシック\ W9.ttc 1 3464676)))
((Hiragino\ Kaku\ Gothic\ Pro W3) ((ヒラギノ角ゴ\ Pro\ W3.otf 0 9362284) (ヒラギノ角ゴシック\ W3.ttc 3 7891480) (ヒラギノ角ゴ\ Pro\ W3.otf 0 9362244)))
((Hiragino\ Kaku\ Gothic\ Pro W6) ((ヒラギノ角ゴ\ Pro\ W6.otf 0 8871612) (ヒラギノ角ゴシック\ W6.ttc 3 7998200) (ヒラギノ角ゴ\ Pro\ W6.otf 0 8871572)))
((Hiragino\ Kaku\ Gothic\ ProN W3) ((ヒラギノ角ゴ\ ProN\ W3.otf 0 7508224) (ヒラギノ角ゴシック\ W3.ttc 2 7891480) (ヒラギノ角ゴ\ ProN\ W3.otf 0 7476024)))
((Hiragino\ Kaku\ Gothic\ ProN W6) ((ヒラギノ角ゴ\ ProN\ W6.otf 0 7555872) (ヒラギノ角ゴシック\ W6.ttc 2 7998200) (ヒラギノ角ゴ\ ProN\ W6.otf 0 7523672)))
((Hiragino\ Kaku\ Gothic\ Std W8) ((ヒラギノ角ゴ\ Std\ W8.otf 0 4276784) (ヒラギノ角ゴシック\ W8.ttc 2 4096288) (ヒラギノ角ゴ\ Std\ W8.otf 0 4276744)))
((Hiragino\ Kaku\ Gothic\ StdN W8) ((ヒラギノ角ゴ\ StdN\ W8.otf 0 3665584) (ヒラギノ角ゴシック\ W8.ttc 3 4096288) (ヒラギノ角ゴ\ StdN\ W8.otf 0 3639612)))
((Hiragino\ Maru\ Gothic\ Pro W4) ((ヒラギノ丸ゴ\ Pro\ W4.otf 0 10109552) (ヒラギノ丸ゴ\ ProN\ W4.ttc 0 11409608) (ヒラギノ丸ゴ\ Pro\ W4.otf 0 10109512)))
((Hiragino\ Maru\ Gothic\ ProN W4) ((ヒラギノ丸ゴ\ ProN\ W4.otf 0 9301332) (ヒラギノ丸ゴ\ ProN\ W4.ttc 1 11409608) (ヒラギノ丸ゴ\ ProN\ W4.otf 0 9269132)))
((Hiragino\ Mincho\ Pro W3) ((ヒラギノ明朝\ Pro\ W3.otf 0 11580728) (ヒラギノ明朝\ ProN\ W3.ttc 1 11867472) (ヒラギノ明朝\ Pro\ W3.otf 0 11580692)))
((Hiragino\ Mincho\ Pro W6) ((ヒラギノ明朝\ Pro\ W6.otf 0 11092140) (ヒラギノ明朝\ ProN\ W6.ttc 1 11975732) (ヒラギノ明朝\ Pro\ W6.otf 0 11092104)))
((Hiragino\ Mincho\ ProN W3) ((ヒラギノ明朝\ ProN\ W3.otf 0 9731332) (ヒラギノ明朝\ ProN\ W3.ttc 0 11867472) (ヒラギノ明朝\ ProN\ W3.otf 0 9699132)))
((Hiragino\ Mincho\ ProN W6) ((ヒラギノ明朝\ ProN\ W6.otf 0 9842776) (ヒラギノ明朝\ ProN\ W6.ttc 0 11975732) (ヒラギノ明朝\ ProN\ W6.otf 0 9810576)))
((Hiragino\ Sans W0) ((ヒラギノ角ゴシック\ W0.ttc 0 3567792)))
((Hiragino\ Sans W1) ((ヒラギノ角ゴシック\ W1.ttc 0 7286744)))
((Hiragino\ Sans W2) ((ヒラギノ角ゴシック\ W2.ttc 0 7270552)))
((Hiragino\ Sans W3) ((ヒラギノ角ゴシック\ W3.ttc 0 7891480)))
((Hiragino\ Sans W4) ((ヒラギノ角ゴシック\ W4.ttc 0 7259328)))
((Hiragino\ Sans W5) ((ヒラギノ角ゴシック\ W5.ttc 0 7260984)))
((Hiragino\ Sans W6) ((ヒラギノ角ゴシック\ W6.ttc 0 7998200)))
((Hiragino\ Sans W7) ((ヒラギノ角ゴシック\ W7.ttc 0 3607768)))
((Hiragino\ Sans W8) ((ヒラギノ角ゴシック\ W8.ttc 0 4096288)))
((Hiragino\ Sans W9) ((ヒラギノ角ゴシック\ W9.ttc 0 3464676)))
((Hiragino\ Sans\ GB W3) ((Hiragino\ Sans\ GB\ W3.otf 0 13176596) (Hiragino\ Sans\ GB\ W3.ttc 0 13179472) (Hiragino\ Sans\ GB\ W3.otf 0 13178508)))
((Hiragino\ Sans\ GB W6) ((Hiragino\ Sans\ GB\ W6.otf 0 13238616) (Hiragino\ Sans\ GB\ W6.ttc 0 13241340) (Hiragino\ Sans\ GB\ W6.otf 0 13240508)))
((Hiragino\ Sans\ GB\ Interface W3) ((Hiragino\ Sans\ GB\ W3.ttc 1 13179472)))
((Hiragino\ Sans\ GB\ Interface W6) ((Hiragino\ Sans\ GB\ W6.ttc 1 13241340)))
((Hoefler\ Text Black) ((Hoefler\ Text.ttc 1 1626664) (Hoefler\ Text.ttc 1 1633680)))
((Hoefler\ Text Black\ Italic) ((Hoefler\ Text.ttc 3 1626664) (Hoefler\ Text.ttc 3 1633680)))
((Hoefler\ Text Italic) ((Hoefler\ Text.ttc 2 1626664) (Hoefler\ Text.ttc 2 1633680)))
((Hoefler\ Text Ornaments) ((Hoefler\ Text\ Ornaments.ttf 0 40744) (Hoefler\ Text\ Ornaments.ttf 0 40988)))
((Hoefler\ Text Regular) ((Hoefler\ Text.ttc 0 1626664) (Hoefler\ Text.ttc 0 1633680)))
((Impact Regular) ((Impact.ttf 0 138488) (impact.ttf 0 137448)))
((InaiMathi Regular) ((InaiMathi.ttf 0 228792) (InaiMathi.ttf 0 260064) (InaiMathi.ttf 0 263572)))
((Iowan\ Old\ Style Black) ((Iowan\ Old\ Style.ttc 4 3356712)))
((Iowan\ Old\ Style Black\ Italic) ((Iowan\ Old\ Style.ttc 5 3356712)))
((Iowan\ Old\ Style Bold) ((Iowan\ Old\ Style.ttc 1 3356712)))
((Iowan\ Old\ Style Bold\ Italic) ((Iowan\ Old\ Style.ttc 3 3356712)))
((Iowan\ Old\ Style Italic) ((Iowan\ Old\ Style.ttc 2 3356712)))
((Iowan\ Old\ Style Roman) ((Iowan\ Old\ Style.ttc 0 3356712)))
((Iowan\ Old\ Style Titling) ((Iowan\ Old\ Style.ttc 6 3356712)))
((IPAGothic Regular) ((ipag.ttf 0 2890224)))
((IPAMincho Regular) ((ipam.ttf 0 3581092)))
((IPAPGothic Regular) ((ipagp.ttf 0 2890444)))
((IPAPMincho Regular) ((ipamp.ttf 0 3581116)))
((IPAUIGothic Regular) ((ipagui.ttf 0 2890480)))
((Isabella Medium) ((Isabella.ttf 0 144636)))
((ISL_Andvari Regular) ((andvari.ttf 0 17188)))
((ISL_Jupiter Regular) ((jupiter.ttf 0 26552)))
((ITF\ Devanagari Bold) ((ITFDevanagari.ttc 1 826144)))
((ITF\ Devanagari Book) ((ITFDevanagari.ttc 0 826144)))
((ITF\ Devanagari Demi) ((ITFDevanagari.ttc 2 826144)))
((ITF\ Devanagari Light) ((ITFDevanagari.ttc 3 826144)))
((ITF\ Devanagari Medium) ((ITFDevanagari.ttc 4 826144)))
((ITF\ Devanagari\ Marathi Bold) ((ITFDevanagari.ttc 6 826144)))
((ITF\ Devanagari\ Marathi Book) ((ITFDevanagari.ttc 5 826144)))
((ITF\ Devanagari\ Marathi Demi) ((ITFDevanagari.ttc 7 826144)))
((ITF\ Devanagari\ Marathi Light) ((ITFDevanagari.ttc 8 826144)))
((ITF\ Devanagari\ Marathi Medium) ((ITFDevanagari.ttc 9 826144)))
((Itsadzoke Regular) ((itsadzoke-046.otf 0 525784)))
((ItsadzokeS01 Regular) ((itsadzokeS01-046.otf 0 672520)))
((ItsadzokeS02 Regular) ((itsadzokeS02.otf 0 643452)))
((Junicode Bold) ((Junicode-Bold.ttf 0 420380) (Junicode-Bold.ttf 0 151944)))
((Junicode Bold\ Italic) ((Junicode-BoldItalic.ttf 0 317172) (Junicode-BoldItalic.ttf 0 107064)))
((Junicode Italic) ((Junicode-Italic.ttf 0 961024) (Junicode-Italic.ttf 0 463156)))
((Junicode Regular) ((Junicode.ttf 0 1369504) (Junicode-Regular.ttf 0 1369504) (Junicode-Regular.ttf 0 770972)))
((Jura Book) ((JuraBook.ttf 0 59000)))
((Jura DemiBold) ((JuraDemiBold.ttf 0 59448)))
((Jura Light) ((JuraLight.ttf 0 58180)))
((Jura Medium) ((JuraMedium.ttf 0 58388)))
((Justus Bold) ((Justus-Bold.ttf 0 35772)))
((Justus Italic) ((Justus-Italic.ttf 0 37172)))
((Justus ItalicOldstyle) ((Justus-ItalicOldstyle.ttf 0 37788)))
((Justus Oldstyle) ((Justus-Oldstyle.ttf 0 42400)))
((Justus Roman) ((Justus-Roman.ttf 0 42512)))
((Justus Versalitas) ((Justus-Versalitas.ttf 0 36428)))
((KacstOne Medium) ((KacstOne.ttf 0 51368)))
((Kai Regular) ((Kai.ttf 0 7888604)))
((Kailasa Bold) ((Kailasa.ttc 1 1175268)))
((Kailasa Regular) ((Kailasa.ttf 0 594792) (Kailasa.ttc 0 1175268) (Kailasa.ttf 0 620764)))
((Kaiti\ SC Black) ((Kaiti.ttc 0 70712356) (楷体.ttc 0 23433244)))
((Kaiti\ SC Bold) ((Kaiti.ttc 1 70712356) (楷体.ttc 1 23433244)))
((Kaiti\ SC Regular) ((Kaiti.ttc 3 70712356) (楷体.ttc 2 23433244)))
((Kaiti\ TC Bold) ((Kaiti.ttc 2 70712356)))
((Kaiti\ TC Regular) ((Kaiti.ttc 5 70712356)))
((KaiTi_GB2312 Regular) ((simkai.ttf 0 4135804)))
((Kannada\ MN Bold) ((Kannada\ MN.ttc 1 1148468) (Kannada\ MN.ttc 1 1151416)))
((Kannada\ MN Regular) ((Kannada\ MN.ttc 0 1148468) (Kannada\ MN.ttc 0 1151416)))
((Kannada\ Sangam\ MN Bold) ((Kannada\ Sangam\ MN.ttc 1 1031232) (Kannada\ Sangam\ MN.ttc 1 1032408)))
((Kannada\ Sangam\ MN Regular) ((Kannada\ Sangam\ MN.ttc 0 1031232) (Kannada\ Sangam\ MN.ttc 0 1032408)))
((Kartika Regular) ((kartika.ttf 0 121452)))
((Kawoszeh Medium) ((kawoszeh.otf 0 143952) (kawoszeh.ttf 0 188828)))
((Kedage Bold) ((Kedage-b.ttf 0 95404)))
((Kedage Normal) ((Kedage-n.ttf 0 100056)))
((Kefa Bold) ((Kefa.ttc 1 389880) (Kefa.ttc 1 391476)))
((Kefa Regular) ((Kefa.ttc 0 389880) (Kefa.ttc 0 391476)))
((Keyboard Regular) ((Keyboard.ttf 0 28564) (Keyboard.ttf 0 55840) (Keyboard.ttf 0 17700)))
((Keytin Regular) ((Keytin-Light.ttf 0 102580)))
((Khmer\ MN Bold) ((Khmer\ MN.ttc 1 727504) (Khmer\ MN.ttc 1 727456)))
((Khmer\ MN Regular) ((Khmer\ MN.ttc 0 727504) (Khmer\ MN.ttc 0 727456)))
((Khmer\ OS Regular) ((KhmerOS.ttf 0 265552)))
((Khmer\ OS\ System Regular) ((KhmerOSsys.ttf 0 265624)))
((Khmer\ Sangam\ MN Regular) ((Khmer\ Sangam\ MN.ttf 0 278472) (Khmer\ Sangam\ MN.ttf 0 278444)))
((Kinnari Bold) ((Kinnari-Bold.ttf 0 69228)))
((Kinnari BoldItalic) ((Kinnari-BoldItalic.ttf 0 81604)))
((Kinnari BoldOblique) ((Kinnari-BoldOblique.ttf 0 79888)))
((Kinnari Italic) ((Kinnari-Italic.ttf 0 80640)))
((Kinnari Medium) ((Kinnari.ttf 0 69412)))
((Kinnari Oblique) ((Kinnari-Oblique.ttf 0 80472)))
((Klee Demibold) ((Klee.ttc 0 14802804)))
((Klee Medium) ((Klee.ttc 1 14802804)))
((Kochi\ Gothic Regular) ((kochi-gothic.ttf 0 4254160)))
((Kohinoor\ Bangla Bold) ((KohinoorBangla.ttc 3 635128)))
((Kohinoor\ Bangla Light) ((KohinoorBangla.ttc 4 635128)))
((Kohinoor\ Bangla Medium) ((KohinoorBangla.ttc 2 635128)))
((Kohinoor\ Bangla Regular) ((KohinoorBangla.ttc 0 635128)))
((Kohinoor\ Bangla Semibold) ((KohinoorBangla.ttc 1 635128)))
((Kohinoor\ Devanagari Bold) ((Kohinoor.ttc 3 907504)))
((Kohinoor\ Devanagari Light) ((Kohinoor.ttc 4 907504)))
((Kohinoor\ Devanagari Medium) ((Kohinoor.ttc 1 907504)))
((Kohinoor\ Devanagari Regular) ((Kohinoor.ttc 0 907504)))
((Kohinoor\ Devanagari Semibold) ((Kohinoor.ttc 2 907504)))
((Kohinoor\ Telugu Bold) ((KohinoorTelugu.ttc 3 343244)))
((Kohinoor\ Telugu Light) ((KohinoorTelugu.ttc 4 343244)))
((Kohinoor\ Telugu Regular) ((KohinoorTelugu.ttc 0 343244) (KohinoorTelugu.ttc 2 343244)))
((Kohinoor\ Telugu\ Semibold Regular) ((KohinoorTelugu.ttc 1 343244)))
((Kokonor Regular) ((Kokonor.ttf 0 1006136) (Kokonor.ttf 0 973544) (Kokonor.ttf 0 974272)))
((Krungthep Regular) ((Krungthep.ttf 0 183036) (Krungthep.ttf 0 186800) (Krungthep.ttf 0 187608)))
((KufiStandardGK Regular) ((KufiStandardGK.ttf 0 79292) (KufiStandardGK.ttc 0 85588) (KufiStandardGK.ttf 0 79988)))
((KufiStandardGK\ PUA Regular) ((KufiStandardGK.ttc 1 85588)))
((Lampoon Regular) ((lampoon.ttf 0 11836)))
((Lantinghei\ SC Demibold) ((Lantinghei.ttc 0 43196124)))
((Lantinghei\ SC Extralight) ((Lantinghei.ttc 1 43196124)))
((Lantinghei\ SC Heavy) ((Lantinghei.ttc 2 43196124)))
((Lantinghei\ TC Demibold) ((Lantinghei.ttc 3 43196124)))
((Lantinghei\ TC Extralight) ((Lantinghei.ttc 4 43196124)))
((Lantinghei\ TC Heavy) ((Lantinghei.ttc 5 43196124)))
((Lao\ MN Bold) ((Lao\ MN.ttc 1 174672) (Lao\ MN.ttc 1 173580)))
((Lao\ MN Regular) ((Lao\ MN.ttc 0 174672) (Lao\ MN.ttc 0 173580)))
((Lao\ Sangam\ MN Regular) ((Lao\ Sangam\ MN.ttf 0 88532) (Lao\ Sangam\ MN.ttf 0 88000)))
((LastResort Regular) ((LastResort.ttf 0 13894924) (LastResort.ttf 0 3044) (LastResort.ttf 0 538692)))
((Latha Regular) ((latha.ttf 0 73292)))
((Lato Black) ((Lato-Bla.ttf 0 114588) (Lato-Black.ttf 0 114588) (Lato-Black.ttf 0 89916)))
((Lato Black\ Italic) ((Lato-BlaIta.ttf 0 111616) (Lato-BlackItalic.ttf 0 111616) (Lato-BlackItalic.ttf 0 82000)))
((Lato Bold) ((Lato-Bol.ttf 0 121788) (Lato-Bold.ttf 0 121788) (Lato-Bold.ttf 0 93688)))
((Lato Bold\ Italic) ((Lato-BolIta.ttf 0 120312) (Lato-BoldItalic.ttf 0 120312) (Lato-BoldItalic.ttf 0 82396)))
((Lato Hairline) ((Lato-Hai.ttf 0 115316) (Lato-Hairline.ttf 0 115316) (Lato-Hairline.ttf 0 128508)))
((Lato Hairline\ Italic) ((Lato-HaiIta.ttf 0 91460) (Lato-HairlineItalic.ttf 0 91460) (Lato-HairlineItalic.ttf 0 96680)))
((Lato Italic) ((Lato-RegIta.ttf 0 118352) (Lato-Italic.ttf 0 118352) (Lato-Italic.ttf 0 84140)))
((Lato Light) ((Lato-Lig.ttf 0 122524) (Lato-Light.ttf 0 122524) (Lato-Light.ttf 0 111012)))
((Lato Light\ Italic) ((Lato-LigIta.ttf 0 91600) (Lato-LightItalic.ttf 0 91600) (Lato-LightItalic.ttf 0 80252)))
((Lato Regular) ((Lato-Reg.ttf 0 120196) (Lato-Regular.ttf 0 120196) (Lato-Regular.ttf 0 96512)))
((Liberation\ Mono Bold) ((LiberationMono-Bold.ttf 0 105048) (LiberationMono-Bold.ttf 0 105116)))
((Liberation\ Mono Bold\ Italic) ((LiberationMono-BoldItalic.ttf 0 118112) (LiberationMono-BoldItalic.ttf 0 117800)))
((Liberation\ Mono Italic) ((LiberationMono-Italic.ttf 0 123304) (LiberationMono-Italic.ttf 0 123804)))
((Liberation\ Mono Regular) ((LiberationMono-Regular.ttf 0 108168) (LiberationMono-Regular.ttf 0 107696)))
((Liberation\ Sans Bold) ((LiberationSans-Bold.ttf 0 133488) (LiberationSans-Bold.ttf 0 139008)))
((Liberation\ Sans Bold\ Italic) ((LiberationSans-BoldItalic.ttf 0 128968) (LiberationSans-BoldItalic.ttf 0 134548)))
((Liberation\ Sans Italic) ((LiberationSans-Italic.ttf 0 155452) (LiberationSans-Italic.ttf 0 161020)))
((Liberation\ Sans Regular) ((LiberationSans-Regular.ttf 0 133828) (LiberationSans-Regular.ttf 0 139280)))
((Liberation\ Serif Bold) ((LiberationSerif-Bold.ttf 0 141180) (LiberationSerif-Bold.ttf 0 146184)))
((Liberation\ Serif Bold\ Italic) ((LiberationSerif-BoldItalic.ttf 0 144280) (LiberationSerif-BoldItalic.ttf 0 149804)))
((Liberation\ Serif Italic) ((LiberationSerif-Italic.ttf 0 138448) (LiberationSerif-Italic.ttf 0 143432)))
((Liberation\ Serif Regular) ((LiberationSerif-Regular.ttf 0 146324) (LiberationSerif-Regular.ttf 0 151480)))
((Libian\ SC Regular) ((Libian.ttc 0 7528132)))
((LiHei\ Pro Medium) ((儷黑\ Pro.ttf 0 10823828) (儷黑\ Pro.ttf 0 6977160)))
((Lilith Regular) ((fuente\ lilith.ttf 0 29312)))
((Linesquare\ Rounded Extended) ((linesquare_rounded_extended.ttf 0 56296)))
((Linux\ Biolinum Bold) ((LinBiolinum_RB.ttf 0 755872)))
((Linux\ Biolinum Italic) ((LinBiolinum_RI.ttf 0 838996)))
((Linux\ Biolinum Regular) ((LinBiolinum_R.ttf 0 763168)))
((Linux\ Biolinum\ Capitals Bold\ Small\ Caps) ((LinBiolinum_aSB.ttf 0 752004)))
((Linux\ Biolinum\ Capitals Italic\ Samll\ Caps) ((LinBiolinum_aSI.ttf 0 834824)))
((Linux\ Biolinum\ Capitals Small\ Caps) ((LinBiolinum_aS.ttf 0 760200)))
((Linux\ Biolinum\ Keyboard Regular) ((LinBiolinum_K.ttf 0 260632)))
((Linux\ Biolinum\ Outline Bold) ((LinBiolinum_aUB.ttf 0 1556244)))
((Linux\ Biolinum\ Outline Italic) ((LinBiolinum_aUI.ttf 0 1817568)))
((Linux\ Biolinum\ Outline Regular) ((LinBiolinum_aU.ttf 0 1561212)))
((Linux\ Biolinum\ Shadow Bold) ((LinBiolinum_aWB.ttf 0 1531508)))
((Linux\ Biolinum\ Shadow Italic) ((LinBiolinum_aWI.ttf 0 1578504)))
((Linux\ Biolinum\ Shadow Regular) ((LinBiolinum_aW.ttf 0 1515372)))
((Linux\ Biolinum\ Slanted Bold\ Slanted) ((LinBiolinum_aBL.ttf 0 798160)))
((Linux\ Biolinum\ Slanted Slanted) ((LinBiolinum_aRL.ttf 0 835804)))
((Linux\ Libertine Bold) ((LinLibertine_RB.ttf 0 834472)))
((Linux\ Libertine Bold\ Italic) ((LinLibertine_RBI.ttf 0 596808)))
((Linux\ Libertine Italic) ((LinLibertine_RI.ttf 0 852768)))
((Linux\ Libertine Regular) ((LinLibertine_R.ttf 0 906980)))
((Linux\ Libertine Semibold) ((LinLibertine_RZ.ttf 0 771388)))
((Linux\ Libertine Semibold\ Italic) ((LinLibertine_RZI.ttf 0 870052)))
((Linux\ Libertine\ Capitals Bold\ Small\ Caps) ((LinLibertine_aBS.ttf 0 833160)))
((Linux\ Libertine\ Capitals Italic) ((LinLibertine_aSI.ttf 0 849064)))
((Linux\ Libertine\ Capitals Semibold\ Italic\ Samll\ Caps) ((LinLibertine_aSZI.ttf 0 869964)))
((Linux\ Libertine\ Capitals Small\ Caps) ((LinLibertine_aS.ttf 0 904204)))
((Linux\ Libertine\ Display Regular) ((LinLibertine_DR.ttf 0 767840)))
((Linux\ Libertine\ Display\ Capitals Small\ Caps) ((LinLibertine_aDRS.ttf 0 768032)))
((Linux\ Libertine\ Initials Initials) ((LinLibertine_I.ttf 0 282676)))
((Linux\ Libertine\ Slanted Bold\ Slanted) ((LinLibertine_aBL.ttf 0 879624)))
((Linux\ Libertine\ Slanted Semibold\ Slanted) ((LinLibertine_aZL.ttf 0 807272)))
((Linux\ Libertine\ Slanted Slanted) ((LinLibertine_aRL.ttf 0 976416)))
((LiSong\ Pro Light) ((儷宋\ Pro.ttf 0 17965572) (儷宋\ Pro.ttf 0 14119008)))
((LiSu Regular) ((simli.ttf 0 9223160)))
((Litos\ Script Italic) ((Litos\ Script\ Italic.otf 0 54008)))
((Litos\ Script Regular) ((Litos\ Script\ regular.otf 0 71900)))
((Litos\ Script SemiBold) ((Litos\ Script\ BOLD.otf 0 258100)))
((Litos\ Script SemiBold\ Italic) ((Litos\ Script_BOLD\ Italic.otf 0 47288)))
((Livia Medium) ((Livia\ Medium.ttf 0 17020)))
((LMTypewriter10\ Regular Regular) ((lmtypewriter10-regular.ttf 0 128340)))
((Lohit\ Bengali Regular) ((lohit_bn.ttf 0 141352)))
((Lohit\ Gujarati Regular) ((lohit_gu.ttf 0 79860)))
((Lohit\ Hindi Regular) ((lohit_hi.ttf 0 81484)))
((Lohit\ Punjabi Regular) ((lohit_pa.ttf 0 25852)))
((Lohit\ Tamil Regular) ((lohit_ta.ttf 0 67688)))
((Loma Bold) ((Loma-Bold.ttf 0 69352)))
((Loma BoldOblique) ((Loma-BoldOblique.ttf 0 80500)))
((Loma Book) ((Loma.ttf 0 70412)))
((Loma Oblique) ((Loma-Oblique.ttf 0 83544)))
((Lucida\ Console Regular) ((lucon.ttf 0 115068)))
((Lucida\ Grande Bold) ((LucidaGrande.ttc 1 1757684) (LucidaGrande.ttc 1 3181856) (LucidaGrande.ttc 1 1746028)))
((Lucida\ Grande Regular) ((LucidaGrande.ttc 0 1757684) (LucidaGrande.ttc 0 3181856) (LucidaGrande.ttc 0 1746028)))
((Lucida\ Sans Demibold\ Italic) ((lsansdi.ttf 0 60664)))
((Lucida\ Sans Demibold\ Roman) ((lsansd.ttf 0 54320)))
((Lucida\ Sans Italic) ((lsansi.ttf 0 59636)))
((Lucida\ Sans Regular) ((lsans.ttf 0 58740)))
((Lucida\ Sans\ Unicode Regular) ((l_10646.ttf 0 323980)))
((Luminari Regular) ((Luminari.ttf 0 553520)))
((Luxi\ Mono Bold) ((luximb.ttf 0 74076)))
((Luxi\ Mono Bold\ Oblique) ((luximbi.ttf 0 69872)))
((Luxi\ Mono Oblique) ((luximri.ttf 0 69496)))
((Luxi\ Mono Regular) ((luximr.ttf 0 71784)))
((Luxi\ Sans Bold) ((luxisb.ttf 0 69972)))
((Luxi\ Sans Bold\ Oblique) ((luxisbi.ttf 0 65568)))
((Luxi\ Sans Oblique) ((luxisri.ttf 0 66372)))
((Luxi\ Sans Regular) ((luxisr.ttf 0 67548)))
((Luxi\ Serif Bold) ((luxirb.ttf 0 87160)))
((Luxi\ Serif Bold\ Oblique) ((luxirbi.ttf 0 85756)))
((Luxi\ Serif Oblique) ((luxirri.ttf 0 86396)))
((Luxi\ Serif Regular) ((luxirr.ttf 0 88732)))
((Maassslicer Regular) ((maass\ slicer\ Italic.ttf 0 116984)))
((Making\ a\ List\ Checking\ it\ Twice Regular) ((Making\ a\ List,\ Checking\ it\ Twice.ttf 0 92140) (MakingaListCheckingItTwice.otf 0 32296)))
((Malayalam\ MN Bold) ((Malayalam\ MN.ttc 1 336580) (Malayalam\ MN.ttc 1 337216)))
((Malayalam\ MN Regular) ((Malayalam\ MN.ttc 0 336580) (Malayalam\ MN.ttc 0 337216)))
((Malayalam\ Sangam\ MN Bold) ((Malayalam\ Sangam\ MN.ttc 1 330892) (Malayalam\ Sangam\ MN.ttc 1 330864)))
((Malayalam\ Sangam\ MN Regular) ((Malayalam\ Sangam\ MN.ttc 0 330892) (Malayalam\ Sangam\ MN.ttc 0 330864)))
((Mallige Bold) ((Malige-b.ttf 0 104412)))
((Mallige Normal) ((Malige-n.ttf 0 121500)))
((Mangal Regular) ((mangal.ttf 0 143864)))
((Marion Bold) ((Marion.ttc 2 915352) (Marion.ttc 2 705260)))
((Marion Italic) ((Marion.ttc 1 915352) (Marion.ttc 1 705260)))
((Marion Regular) ((Marion.ttc 0 915352) (Marion.ttc 0 705260)))
((Marker\ Felt Thin) ((MarkerFelt.ttc 0 544364) (MarkerFelt.ttc 0 621152) (MarkerFelt.ttc 0 650364)))
((Marker\ Felt Wide) ((MarkerFelt.ttc 1 544364) (MarkerFelt.ttc 1 621152) (MarkerFelt.ttc 1 650364)))
((Marlett Regular) ((marlett.ttf 0 24124)))
((MarVoSym Regular) ((marvosym.ttf 0 69792)))
((Meera Regular) ((Meera_04.ttf 0 334404)))
((Menlo Bold) ((Menlo.ttc 1 2172912) (Menlo.ttc 1 2140384) (Menlo.ttc 1 2144600)))
((Menlo Bold\ Italic) ((Menlo.ttc 3 2172912) (Menlo.ttc 3 2140384) (Menlo.ttc 3 2144600)))
((Menlo Italic) ((Menlo.ttc 2 2172912) (Menlo.ttc 2 2140384) (Menlo.ttc 2 2144600)))
((Menlo Regular) ((Menlo.ttc 0 2172912) (Menlo.ttc 0 2140384) (Menlo.ttc 0 2144600)))
((Meyne\ Textur Regular) ((meyne_textur.ttf 0 81588)))
((Microsoft\ Sans\ Serif Regular) ((Microsoft\ Sans\ Serif.ttf 0 652248) (micross.ttf 0 461672)))
((Mikodacs Regular) ((Mikodacs.otf 0 238596)))
((MikodacsPCS Regular) ((MikodacsPCS.otf 0 130460)))
((MingLiU Regular) ((MingLiU.ttf 0 6272080)))
((Mishafi Regular) ((Mishafi.ttf 0 1425292)))
((Mishafi\ Gold Regular) ((Mishafi\ Gold.ttf 0 658260)))
((Monteiro\ Lobato Regular) ((lobato.ttf 0 82204)))
((MPH\ 2B\ Damase Regular) ((damase_v.2.ttf 0 900260)))
((MS\ Gothic Regular) ((MS\ Gothic.ttf 0 7203212)))
((MS\ Mincho Regular) ((MS\ Mincho.ttf 0 9081312)))
((Mshtakan Bold) ((MshtakanBold.ttf 0 37320) (Mshtakan.ttc 2 169024)))
((Mshtakan BoldOblique) ((MshtakanBoldOblique.ttf 0 41400) (Mshtakan.ttc 3 169024)))
((Mshtakan Oblique) ((MshtakanOblique.ttf 0 51360) (Mshtakan.ttc 1 169024)))
((Mshtakan Regular) ((MshtakanRegular.ttf 0 46172) (Mshtakan.ttc 0 169024)))
((Mukti Narrow) ((MuktiNarrow.ttf 0 185512)))
((Mukti Narrow\ Bold) ((MuktiNarrowBold.ttf 0 73936)))
((Muna Black) ((Muna.ttc 4 197916)))
((Muna Bold) ((Muna.ttc 2 197916)))
((Muna Regular) ((Muna.ttc 0 197916)))
((Muna\ PUA Black) ((Muna.ttc 5 197916)))
((Muna\ PUA Bold) ((Muna.ttc 3 197916)))
((Muna\ PUA Regular) ((Muna.ttc 1 197916)))
((MV\ Boli Regular) ((mvboli.ttf 0 40500)))
((Myanmar\ MN Bold) ((Myanmar\ MN.ttc 1 444600) (Myanmar\ MN.ttc 1 445116)))
((Myanmar\ MN Regular) ((Myanmar\ MN.ttc 0 444600) (Myanmar\ MN.ttc 0 445116)))
((Myanmar\ Sangam\ MN Bold) ((Myanmar\ Sangam\ MN.ttc 1 300584)))
((Myanmar\ Sangam\ MN Regular) ((Myanmar\ Sangam\ MN.ttc 0 300584) (Myanmar\ Sangam\ MN.ttf 0 200600)))
((Nadeem Regular) ((Nadeem.ttf 0 59096) (Nadeem.ttc 0 59452) (Nadeem.ttf 0 59452)))
((Nadeem\ PUA Regular) ((Nadeem.ttc 1 59452)))
((Nanum\ Brush\ Script Regular) ((NanumScript.ttc 0 7212984) (NanumScript.ttc 0 7242476)))
((Nanum\ Pen\ Script Regular) ((NanumScript.ttc 1 7212984) (NanumScript.ttc 1 7242476)))
((NanumGothic Bold) ((NanumGothic.ttc 1 12792016) (NanumGothic.ttc 1 12790388)))
((NanumGothic ExtraBold) ((NanumGothic.ttc 2 12792016) (NanumGothic.ttc 2 12790388)))
((NanumGothic Regular) ((NanumGothic.ttc 0 12792016) (NanumGothic.ttc 0 12790388)))
((NanumMyeongjo Bold) ((NanumMyeongjo.ttc 1 13175240) (NanumMyeongjo.ttc 1 13193888)))
((NanumMyeongjo ExtraBold) ((NanumMyeongjo.ttc 2 13175240) (NanumMyeongjo.ttc 2 13193888)))
((NanumMyeongjo Regular) ((NanumMyeongjo.ttc 0 13175240) (NanumMyeongjo.ttc 0 13193888)))
((New\ Peninim\ MT Bold) ((NewPeninimMTBold.ttf 0 48116) (NewPeninimMT.ttc 3 148656)))
((New\ Peninim\ MT Bold\ Inclined) ((NewPeninimMTBoldInclined.ttf 0 50384) (NewPeninimMT.ttc 2 148656)))
((New\ Peninim\ MT Inclined) ((NewPeninimMTInclined.ttf 0 44520) (NewPeninimMT.ttc 1 148656)))
((New\ Peninim\ MT Regular) ((NewPeninimMT.ttf 0 43868) (NewPeninimMT.ttc 0 148656)))
((Ninoshandwriting Medium) ((Ninoshandwriting.ttf 0 18688)))
((Norasi Bold) ((Norasi-Bold.ttf 0 102824)))
((Norasi BoldItalic) ((Norasi-BoldItalic.ttf 0 114920)))
((Norasi BoldOblique) ((Norasi-BoldOblique.ttf 0 116420)))
((Norasi Italic) ((Norasi-Italic.ttf 0 117488)))
((Norasi Oblique) ((Norasi-Oblique.ttf 0 118732)))
((Norasi Regular) ((Norasi.ttf 0 104448)))
((Noteworthy Bold) ((Noteworthy.ttc 1 551924) (Noteworthy.ttc 1 427736)))
((Noteworthy Light) ((Noteworthy.ttc 0 551924) (Noteworthy.ttc 0 427736)))
((NTS\ Akkhara Bold) ((NTSAkkhara-Bold.ttf 0 79592)))
((NTS\ Akkhara BoldItalic) ((NTSAkkhara-BoldItalic.ttf 0 86244)))
((NTS\ Akkhara Book) ((NTSAkkhara.ttf 0 76256)))
((NTS\ Akkhara Italic) ((NTSAkkhara-Italic.ttf 0 78984)))
((Odstemplik Bold) ((odstemplikBold.otf 0 113416)))
((Odstemplik Regular) ((odstemplik.otf 0 107392)))
((Oldprint Normal) ((Oldprint.ttf 0 57948)))
((OMGWilliamsSerifs Medium) ((OMGWilliamsSerifs.ttf 0 145204)))
((OMGWriteLikeWilliam Medium) ((OMGWriteLikeWilliam.ttf 0 221208)))
((Open\ Sans Bold) ((OpenSans-Bold.ttf 0 224592)))
((Open\ Sans Bold\ Italic) ((OpenSans-BoldItalic.ttf 0 213292)))
((Open\ Sans ExtraBold) ((OpenSans-ExtraBold.ttf 0 222584)))
((Open\ Sans ExtraBold\ Italic) ((OpenSans-ExtraBoldItalic.ttf 0 213420)))
((Open\ Sans Italic) ((OpenSans-Italic.ttf 0 212896)))
((Open\ Sans Light) ((OpenSans-Light.ttf 0 222412)))
((Open\ Sans Light\ Condensed) ((OpenSans-CondLight.ttf 0 221108)))
((Open\ Sans Light\ Condensed\ Italic) ((OpenSans-CondLightItalic.ttf 0 210804)))
((Open\ Sans Light\ Italic) ((OpenSans-LightItalic.ttf 0 213128)))
((Open\ Sans Regular) ((OpenSans-Regular.ttf 0 217360)))
((Open\ Sans SemiBold) ((OpenSans-Semibold.ttf 0 221328)))
((Open\ Sans SemiBold\ Italic) ((OpenSans-SemiboldItalic.ttf 0 212820)))
((OpenSymbol Regular) ((opens___.ttf 0 178396)))
((Optima Bold) ((Optima.ttc 1 577460) (Optima.ttc 1 569784) (Optima.ttc 1 567004)))
((Optima Bold\ Italic) ((Optima.ttc 3 577460) (Optima.ttc 3 569784) (Optima.ttc 3 567004)))
((Optima ExtraBlack) ((Optima.ttc 4 577460) (Optima.ttc 4 569784) (Optima.ttc 4 567004)))
((Optima Italic) ((Optima.ttc 2 577460) (Optima.ttc 2 569784) (Optima.ttc 2 567004)))
((Optima Regular) ((Optima.ttc 0 577460) (Optima.ttc 0 569784) (Optima.ttc 0 567004)))
((Oriya\ MN Bold) ((Oriya\ MN.ttc 1 469416) (Oriya\ MN.ttc 1 471280)))
((Oriya\ MN Regular) ((Oriya\ MN.ttc 0 469416) (Oriya\ MN.ttc 0 471280)))
((Oriya\ Sangam\ MN Bold) ((Oriya\ Sangam\ MN.ttc 1 215412) (Oriya\ Sangam\ MN.ttc 1 506260)))
((Oriya\ Sangam\ MN Regular) ((Oriya\ Sangam\ MN.ttc 0 215412) (Oriya\ Sangam\ MN.ttc 0 506260)))
((Osaka Regular) ((Osaka.ttf 0 3631328) (Osaka.ttf 0 3631848)))
((Osaka Regular-Mono) ((OsakaMono.ttf 0 2307144) (OsakaMono.ttf 0 2307664)))
((Overhaul Regular) ((Overhaul.otf 0 761084) (Overhaul.ttf 0 1254464)))
((OxfordCP Regular) ((OxfordCP.otf 0 20224)))
((Pacifico Regular) ((Pacifico.ttf 0 43632)))
((Palatino Bold) ((Palatino.ttc 2 1770652) (Palatino.ttc 2 1701880)))
((Palatino Bold\ Italic) ((Palatino.ttc 3 1770652) (Palatino.ttc 3 1701880)))
((Palatino Italic) ((Palatino.ttc 1 1770652) (Palatino.ttc 1 1701880)))
((Palatino Regular) ((Palatino.ttc 0 1770652) (Palatino.ttc 0 1701880)))
((Palatino\ Linotype Bold) ((palab.ttf 0 434004)))
((Palatino\ Linotype Bold\ Italic) ((palabi.ttf 0 344288)))
((Palatino\ Linotype Italic) ((palai.ttf 0 430800)))
((Palatino\ Linotype Regular) ((pala.ttf 0 489884)))
((Paper\ Cuts\ 2 Regular) ((papercuts-2.ttf 0 32056)))
((Papyrus Condensed) ((Papyrus.ttc 1 208896) (Papyrus.ttc 0 1098704) (Papyrus.ttc 1 210844)))
((Papyrus Regular) ((Papyrus.ttc 0 208896) (Papyrus.ttc 1 1098704) (Papyrus.ttc 0 210844)))
((PCMyungjo Regular) ((PCmyoungjo.ttf 0 9494920) (PCmyoungjo.ttf 0 9450744) (PCmyoungjo.ttf 0 9515016)))
((Penguin\ Attack Regular) ((PenguinAttack.ttf 0 70356)))
((Perfect\ Dark\ Zero Regular) ((Perfect\ Dark\ Zero.ttf 0 18324)))
((Phetsarath\ OT Regular) ((Phetsarath_OT.ttf 0 92828)))
((Phosphate Inline) ((Phosphate.ttc 0 225784)))
((Phosphate Solid) ((Phosphate.ttc 1 225784)))
((PilGi Regular) ((Pilgiche.ttf 0 4676380) (Pilgiche.ttf 0 4635704)))
((PingFang\ HK Light) ((PingFang.ttc 9 70807596) (PingFang.ttc 27 70807596)))
((PingFang\ HK Medium) ((PingFang.ttc 3 70807596) (PingFang.ttc 21 70807596)))
((PingFang\ HK Regular) ((PingFang.ttc 0 70807596) (PingFang.ttc 18 70807596)))
((PingFang\ HK Semibold) ((PingFang.ttc 6 70807596) (PingFang.ttc 24 70807596)))
((PingFang\ HK Thin) ((PingFang.ttc 12 70807596) (PingFang.ttc 30 70807596)))
((PingFang\ HK Ultralight) ((PingFang.ttc 15 70807596) (PingFang.ttc 33 70807596)))
((PingFang\ SC Light) ((PingFang.ttc 11 70807596)))
((PingFang\ SC Medium) ((PingFang.ttc 5 70807596) (PingFang.ttc 23 70807596)))
((PingFang\ SC Regular) ((PingFang.ttc 2 70807596) (PingFang.ttc 20 70807596)))
((PingFang\ SC Semibold) ((PingFang.ttc 8 70807596) (PingFang.ttc 26 70807596)))
((PingFang\ SC Thin) ((PingFang.ttc 14 70807596) (PingFang.ttc 32 70807596)))
((PingFang\ SC Ultralight) ((PingFang.ttc 17 70807596) (PingFang.ttc 35 70807596)))
((PingFang\ SC }0) ((PingFang.ttc 29 70807596)))
((PingFang\ TC Light) ((PingFang.ttc 10 70807596) (PingFang.ttc 28 70807596)))
((PingFang\ TC Medium) ((PingFang.ttc 4 70807596) (PingFang.ttc 22 70807596)))
((PingFang\ TC Regular) ((PingFang.ttc 1 70807596) (PingFang.ttc 19 70807596)))
((PingFang\ TC Semibold) ((PingFang.ttc 7 70807596) (PingFang.ttc 25 70807596)))
((PingFang\ TC Thin) ((PingFang.ttc 13 70807596) (PingFang.ttc 31 70807596)))
((PingFang\ TC Ultralight) ((PingFang.ttc 16 70807596) (PingFang.ttc 34 70807596)))
((PipeSquare\ Rounded Regular) ((PipeSquare\ Rounded.ttf 0 147076)))
((Plantagenet\ Cherokee Regular) ((PlantagenetCherokee.ttf 0 75716) (PlantagenetCherokee.ttf 0 72052) (PlantagenetCherokee.ttf 0 72336)))
((Pointfree Regular) ((pointfree.ttf 0 27052)))
((Portmanteau Regular) ((Portmanteau\ Regular.ttf 0 182028) (Portmanteau-Regular.otf 0 106808)))
((Pothana2000 Regular) ((Pothana2000.ttf 0 194268) (Vemana.ttf 0 200092)))
((Pretzel Regular) ((Pretzel\ Regular.ttf 0 151136) (Pretzel-Regular.otf 0 54532)))
((PreussischeIV44Ausgabe3 Regular) ((Pr_IV_44_Ausg3.otf 0 20508)))
((Prociono Regular) ((Prociono-Regular.otf 0 36512)))
((Promocyja Regular) ((Promocyja096.ttf 0 256300) (Promocyja_096.otf 0 336048)))
((Psicopatologia\ de\ la\ Vida\ Cotidiana Regular) ((freud.ttf 0 55032)))
((PT\ Mono Bold) ((PTMono.ttc 0 309348) (PTM75F.ttf 0 140464)))
((PT\ Mono Regular) ((PTMono.ttc 1 309348) (PTM55F.ttf 0 174592)))
((PT\ Sans Bold) ((PTS75F.ttf 0 458084) (PTSans.ttc 7 2767520) (PTSans.ttc 2 2763792)))
((PT\ Sans Bold\ Caption) ((PTC75F.ttf 0 386624)))
((PT\ Sans Bold\ Italic) ((PTS76F.ttf 0 363048) (PTSans.ttc 6 2767520) (PTSans.ttc 3 2763792)))
((PT\ Sans Bold\ Narrow) ((PTN77F.ttf 0 475564)))
((PT\ Sans Caption) ((PTC55F.ttf 0 430804) (PTSans.ttc 5 2767520) (PTC55F.ttf 0 375036) (PTSans.ttc 4 2763792)))
((PT\ Sans Caption\ Bold) ((PTSans.ttc 4 2767520) (PTC75F.ttf 0 386624) (PTSans.ttc 5 2763792)))
((PT\ Sans Italic) ((PTS56F.ttf 0 424296) (PTSans.ttc 1 2767520) (PTSans.ttc 1 2763792)))
((PT\ Sans Narrow) ((PTN57F.ttf 0 384056) (PTSans.ttc 3 2767520) (PTSans.ttc 6 2763792)))
((PT\ Sans Narrow\ Bold) ((PTSans.ttc 2 2767520) (PTN77F.ttf 0 475564) (PTSans.ttc 7 2763792)))
((PT\ Sans Regular) ((PTS55F.ttf 0 430804) (PTSans.ttc 0 2767520) (PTSans.ttc 0 2763792)))
((PT\ Serif Bold) ((PTF75F.ttf 0 327840) (PTSerif.ttc 3 1151720)))
((PT\ Serif Bold\ Italic) ((PTF76F.ttf 0 325424) (PTSerif.ttc 2 1151720)))
((PT\ Serif Caption) ((PTZ55F.ttf 0 387684) (PTSerifCaption.ttc 0 700100)))
((PT\ Serif Caption\ Italic) ((PTSerifCaption.ttc 1 700100) (PTZ56F.ttf 0 394456)))
((PT\ Serif Italic) ((PTF56F.ttf 0 363200) (PTSerif.ttc 1 1151720)))
((PT\ Serif Italic\ Caption) ((PTZ56F.ttf 0 394456)))
((PT\ Serif Regular) ((PTF55F.ttf 0 346892) (PTSerif.ttc 0 1151720)))
((Purisa Bold) ((Purisa-Bold.ttf 0 142500)))
((Purisa BoldOblique) ((Purisa-BoldOblique.ttf 0 149580)))
((Purisa Medium) ((Purisa.ttf 0 152384)))
((Purisa Oblique) ((Purisa-Oblique.ttf 0 156072)))
((Quadrata\ Preciosa Extended\ Medium) ((Quadrata\ Preciosa\ Extended.ttf 0 51668)))
((Quadrata\ preciosa Medium) ((quadrata\ preciosa.ttf 0 20608)))
((QumpellkaNo12 Regular) ((QumpellkaNo12.otf 0 274120)))
((Raanana Bold) ((RaananaBold.ttf 0 31636) (Raanana.ttc 1 61296) (RaananaBold.ttf 0 31352)))
((Raanana Regular) ((Raanana.ttf 0 32420) (Raanana.ttc 0 61296) (Raanana.ttf 0 32124)))
((Raavi Regular) ((raavi.ttf 0 57348)))
((Rabanera Regular) ((Rabanera-outline-shadow.otf 0 83368) (Rabanera-outline-shadow.ttf 0 134836)))
((Rachana Regular) ((Rachana_04.ttf 0 383408)))
((Rawengulk Bold) ((RawengulkBold.otf 0 104776) (RawengulkBold.ttf 0 132536)))
((Rawengulk Demibold) ((RawengulkDemibold.otf 0 106796) (RawengulkDemibold.ttf 0 129180)))
((Rawengulk Light) ((RawengulkLight.otf 0 109404) (RawengulkLight.ttf 0 143284)))
((Rawengulk Regular) ((RawengulkRegular.otf 0 167952) (RawengulkRegular.ttf 0 193860)))
((Rawengulk Ultralight) ((RawengulkUltralight.otf 0 106708) (RawengulkUltralight.ttf 0 126588)))
((RawengulkPcs Regular) ((RawengulkPcs.otf 0 105212) (RawengulkPcs.ttf 0 123524)))
((RawengulkSans Regular) ((RawengulkSans-094.otf 0 223848) (RawengulkSans-094.ttf 0 284368)))
((Rekha Medium) ((Rekha.ttf 0 83868)))
((Resagnicto Bold) ((ResagnictoBold.ttf 0 118608)))
((Resagnicto Italic) ((ResagnictoItalic.ttf 0 185760)))
((Resagnicto Regular) ((Resagnicto.ttf 0 123728)))
((Resagokr Bold) ((ResagokrBold.otf 0 287520)))
((Resagokr Light) ((ResagokrLight.otf 0 287204)))
((Resagokr Regular) ((Resagokr.otf 0 287896)))
((Reswysokr Regular) ((Reswysokr.otf 0 166036)))
((Ringling Regular) ((ringling.ttf 0 40932)))
((Saab Regular) ((Saab.ttf 0 114092)))
((Sana Regular) ((Sana.ttc 0 74936)))
((Sana\ PUA Regular) ((Sana.ttc 1 74936)))
((Sathu Regular) ((Sathu.ttf 0 269148) (Sathu.ttf 0 414872) (Sathu.ttf 0 416152)))
((Savoye\ LET Plain) ((Savoye\ LET.ttc 0 101512)))
((Savoye\ LET\ CC. Plain) ((Savoye\ LET.ttc 1 101512)))
((Sawasdee Bold) ((Sawasdee-Bold.ttf 0 83576)))
((Sawasdee BoldOblique) ((Sawasdee-BoldOblique.ttf 0 100596)))
((Sawasdee Oblique) ((Sawasdee-Oblique.ttf 0 104276)))
((Sawasdee Regular) ((Sawasdee.ttf 0 86108)))
((Sazanami\ Gothic Gothic-Regular) ((sazanami-gothic.ttf 0 7690324)))
((Sazanami\ Mincho Mincho-Regular) ((sazanami-mincho.ttf 0 10554196)))
((Schwaben\ Alt Bold) ((Schwaben\ Alt\ Bold.ttf 0 69740)))
((Seattle\ Avenue Regular) ((Seattle\ Avenue.ttf 0 45636) (SeattleAvenue.otf 0 22908)))
((Seravek Bold) ((Seravek.ttc 9 4983524)))
((Seravek Bold\ Italic) ((Seravek.ttc 8 4983524)))
((Seravek Italic) ((Seravek.ttc 1 4983524) (Seravek.ttc 2 4983524)))
((Seravek Light) ((Seravek.ttc 5 4983524)))
((Seravek Light\ Italic) ((Seravek.ttc 4 4983524)))
((Seravek Regular) ((Seravek.ttc 0 4983524) (Seravek.ttc 3 4983524)))
((Seravek\ ExtraLight Italic) ((Seravek.ttc 6 4983524)))
((Seravek\ ExtraLight Regular) ((Seravek.ttc 7 4983524)))
((Sertig Light) ((Sertig.otf 0 28912)))
((SF\ NS\ Display Black) ((SFNSDisplay-Black.otf 0 304012)))
((SF\ NS\ Display Bold) ((SFNSDisplay-Bold.otf 0 311816)))
((SF\ NS\ Display Heavy) ((SFNSDisplay-Heavy.otf 0 313040)))
((SF\ NS\ Display Light) ((SFNSDisplay-Light.otf 0 304324)))
((SF\ NS\ Display Medium) ((SFNSDisplay-Medium.otf 0 310712)))
((SF\ NS\ Display Regular) ((SFNSDisplay-Regular.otf 0 291356)))
((SF\ NS\ Display Semibold) ((SFNSDisplay-Semibold.otf 0 312592)))
((SF\ NS\ Display Thin) ((SFNSDisplay-Thin.otf 0 295308)))
((SF\ NS\ Display Ultralight) ((SFNSDisplay-Ultralight.otf 0 294600)))
((SF\ NS\ Text Bold) ((SFNSText-Bold.otf 0 329360)))
((SF\ NS\ Text Bold\ G1) ((SFNSText-BoldG1.otf 0 328928)))
((SF\ NS\ Text Bold\ G2) ((SFNSText-BoldG2.otf 0 328948)))
((SF\ NS\ Text Bold\ G3) ((SFNSText-BoldG3.otf 0 329484)))
((SF\ NS\ Text Bold\ Italic) ((SFNSText-BoldItalic.otf 0 238900)))
((SF\ NS\ Text Bold\ Italic\ G1) ((SFNSText-BoldItalicG1.otf 0 239636)))
((SF\ NS\ Text Bold\ Italic\ G2) ((SFNSText-BoldItalicG2.otf 0 239956)))
((SF\ NS\ Text Bold\ Italic\ G3) ((SFNSText-BoldItalicG3.otf 0 240000)))
((SF\ NS\ Text Heavy) ((SFNSText-Heavy.otf 0 329916)))
((SF\ NS\ Text Heavy\ Italic) ((SFNSText-HeavyItalic.otf 0 240528)))
((SF\ NS\ Text Italic) ((SFNSText-RegularItalic.otf 0 228824)))
((SF\ NS\ Text Italic\ G1) ((SFNSText-RegularItalicG1.otf 0 230992)))
((SF\ NS\ Text Italic\ G2) ((SFNSText-RegularItalicG2.otf 0 231192)))
((SF\ NS\ Text Italic\ G3) ((SFNSText-RegularItalicG3.otf 0 231440)))
((SF\ NS\ Text Light) ((SFNSText-Light.otf 0 325916)))
((SF\ NS\ Text Light\ Italic) ((SFNSText-LightItalic.otf 0 237132)))
((SF\ NS\ Text Medium) ((SFNSText-Medium.otf 0 329308)))
((SF\ NS\ Text Medium\ Italic) ((SFNSText-MediumItalic.otf 0 239252)))
((SF\ NS\ Text Regular) ((SFNSText-Regular.otf 0 317760)))
((SF\ NS\ Text Regular\ G1) ((SFNSText-RegularG1.otf 0 320908)))
((SF\ NS\ Text Regular\ G2) ((SFNSText-RegularG2.otf 0 320296)))
((SF\ NS\ Text Regular\ G3) ((SFNSText-RegularG3.otf 0 320556)))
((SF\ NS\ Text Semibold) ((SFNSText-Semibold.otf 0 328956)))
((SF\ NS\ Text Semibold\ Italic) ((SFNSText-SemiboldItalic.otf 0 239784)))
((Shree\ Devanagari\ 714 Bold) ((Shree714.ttc 1 520156)))
((Shree\ Devanagari\ 714 Bold\ Italic) ((Shree714.ttc 3 520156)))
((Shree\ Devanagari\ 714 Italic) ((Shree714.ttc 2 520156)))
((Shree\ Devanagari\ 714 Regular) ((Shree714.ttc 0 520156)))
((Shruti Regular) ((shruti.ttf 0 234280)))
((SignPainter-HouseScript Regular) ((SignPainter.otf 0 163412)))
((Silom Regular) ((Silom.ttf 0 281848) (Silom.ttf 0 288864) (Silom.ttf 0 289492)))
((SimHei Regular) ((simhei.ttf 0 9751960)))
((SimSun Regular) ((simsun.ttf 0 10499104)))
((Sinhala\ MN Bold) ((Sinhala\ MN.ttc 1 1466440) (Sinhala\ MN.ttc 1 1467868)))
((Sinhala\ MN Regular) ((Sinhala\ MN.ttc 0 1466440) (Sinhala\ MN.ttc 0 1467868)))
((Sinhala\ Sangam\ MN Bold) ((Sinhala\ Sangam\ MN.ttc 1 642408) (Sinhala\ Sangam\ MN.ttc 1 642756)))
((Sinhala\ Sangam\ MN Regular) ((Sinhala\ Sangam\ MN.ttc 0 642408) (Sinhala\ Sangam\ MN.ttc 0 642756)))
((Skia Regular) ((Skia.ttf 0 475656) (Skia.ttf 0 489424)))
((Snell\ Roundhand Black) ((SnellRoundhand.ttc 2 3587668)))
((Snell\ Roundhand Bold) ((SnellRoundhand.ttc 1 3587668)))
((Snell\ Roundhand Regular) ((SnellRoundhand.ttc 0 3587668)))
((Songti\ SC Black) ((Songti.ttc 0 66899384) (宋体.ttc 0 45078972)))
((Songti\ SC Bold) ((Songti.ttc 1 66899384) (宋体.ttc 1 45078972)))
((Songti\ SC Light) ((Songti.ttc 3 66899384) (宋体.ttc 2 45078972)))
((Songti\ SC Regular) ((Songti.ttc 6 66899384) (宋体.ttc 4 45078972)))
((Songti\ TC Bold) ((Songti.ttc 2 66899384)))
((Songti\ TC Light) ((Songti.ttc 5 66899384)))
((Songti\ TC Regular) ((Songti.ttc 7 66899384)))
((Source\ Han\ Sans\ SC Regular) ((SourceHanSansSC-Regular.otf 0 16412776)))
((Source\ Han\ Sans\ SC Bold) ((SourceHanSansSC-Bold.otf 0 16983696)))
((Source\ Han\ Sans\ SC Heavy) ((SourceHanSansSC-Heavy.otf 0 17324776)))
((Source\ Han\ Sans\ SC Medium) ((SourceHanSansSC-Medium.otf 0 16490072)))
((Source\ Han\ Sans\ SC Normal) ((SourceHanSansSC-Normal.otf 0 16353464)))
((Source\ Han\ Sans\ SC Light) ((SourceHanSansSC-Light.otf 0 16229588)))
((Source\ Han\ Sans\ SC ExtraLight) ((SourceHanSansSC-ExtraLight.otf 0 15140064)))
((STFangsong Regular) ((华文仿宋.ttf 0 15734488) (华文仿宋.ttf 0 15884236) (华文仿宋.ttf 0 15884824)))
((STHeiti Light) ((华文细黑.ttf 0 17140620) (华文细黑.ttf 0 15642136) (华文细黑.ttf 0 15692256)))
((STHeiti Regular) ((华文黑体.ttf 0 13631224) (华文黑体.ttf 0 13631780)))
((Stix Bold) ((STIX-Bold.otf 0 209464)))
((Stix Bold\ Italic) ((STIX-BoldItalic.otf 0 174404)))
((Stix Italic) ((STIX-Italic.otf 0 177388)))
((Stix Regular) ((STIX-Regular.otf 0 426992)))
((Stix\ Math Regular) ((STIXMath-Regular.otf 0 477848)))
((STKaiti Regular) ((华文楷体.ttf 0 17502796) (Kaiti.ttc 4 70712356) (楷体.ttc 3 23433244)))
((STSong Regular) ((华文宋体.ttf 0 16163136) (Songti.ttc 4 66899384) (宋体.ttc 3 45078972)))
((Sukhumvit\ Set Bold) ((SukhumvitSet.ttc 5 626056)))
((Sukhumvit\ Set Light) ((SukhumvitSet.ttc 1 626056)))
((Sukhumvit\ Set Medium) ((SukhumvitSet.ttc 3 626056)))
((Sukhumvit\ Set Semi\ Bold) ((SukhumvitSet.ttc 4 626056)))
((Sukhumvit\ Set Text) ((SukhumvitSet.ttc 2 626056)))
((Sukhumvit\ Set Thin) ((SukhumvitSet.ttc 0 626056)))
((Superclarendon Black) ((SuperClarendon.ttc 7 2681496)))
((Superclarendon Black\ Italic) ((SuperClarendon.ttc 6 2681496)))
((Superclarendon Bold) ((SuperClarendon.ttc 5 2681496)))
((Superclarendon Bold\ Italic) ((SuperClarendon.ttc 4 2681496)))
((Superclarendon Italic) ((SuperClarendon.ttc 1 2681496)))
((Superclarendon Light) ((SuperClarendon.ttc 3 2681496)))
((Superclarendon Light\ Italic) ((SuperClarendon.ttc 2 2681496)))
((Superclarendon Regular) ((SuperClarendon.ttc 0 2681496)))
((Sylfaen Regular) ((sylfaen.ttf 0 221676)))
((Symbol Regular) ((Symbol.ttf 0 103400) (symbol.ttf 0 69464) (Symbol.ttf 0 105752)))
((Tabaquera Regular) ((Tabaquera.ttf 0 175964)))
((Tahoma Bold) ((Tahoma\ Bold.ttf 0 626928) (tahomabd.ttf 0 355680)))
((Tahoma Regular) ((Tahoma.ttf 0 681120) (tahoma.ttf 0 383804)))
((TakaoExGothic Regular) ((TakaoExGothic.ttf 0 6008858)))
((TakaoExMincho Regular) ((TakaoExMincho.ttf 0 7754918)))
((TakaoGothic Regular) ((TakaoGothic.ttf 0 6234398)))
((TakaoMincho Regular) ((TakaoMincho.ttf 0 8061610)))
((TakaoPGothic Regular) ((TakaoPGothic.ttf 0 6234746) (ttf-japanese-gothic.ttf 0 6234746)))
((TakaoPMincho Regular) ((TakaoPMincho.ttf 0 8060926) (ttf-japanese-mincho.otf 0 8060926)))
((Tamil\ MN Bold) ((Tamil\ MN.ttc 1 400396) (Tamil\ MN.ttc 1 400164)))
((Tamil\ MN Regular) ((Tamil\ MN.ttc 0 400396) (Tamil\ MN.ttc 0 400164)))
((Tamil\ Sangam\ MN Bold) ((Tamil\ Sangam\ MN.ttc 1 384780) (Tamil\ Sangam\ MN.ttc 1 338136)))
((Tamil\ Sangam\ MN Regular) ((Tamil\ Sangam\ MN.ttc 0 384780) (Tamil\ Sangam\ MN.ttc 0 338136)))
((Tangerine Bold) ((Tangerine_Bold.ttf 0 66492)))
((Tangerine Regular) ((Tangerine_Regular.ttf 0 61484)))
((Telugu\ MN Bold) ((Telugu\ MN.ttc 1 1736356) (Telugu\ MN.ttc 1 1740836)))
((Telugu\ MN Regular) ((Telugu\ MN.ttc 0 1736356) (Telugu\ MN.ttc 0 1740836)))
((Telugu\ Sangam\ MN Bold) ((Telugu\ Sangam\ MN.ttc 1 1224792) (Telugu\ Sangam\ MN.ttc 1 1229264)))
((Telugu\ Sangam\ MN Regular) ((Telugu\ Sangam\ MN.ttc 0 1224792) (Telugu\ Sangam\ MN.ttc 0 1229264)))
((TeX\ AMS\ Blackboard\ Bold Regular) ((msbm10.tfm 0 908)))
((TeX\ Bard) ((bard.tfm 0 924)))
((TeX\ Blackboard\ Bold Bold) ((bbmbx10.tfm 0 580) (bbmbx10.tfm 0 644)))
((TeX\ Blackboard\ Bold Bold Oblique) ((bbmbxsl10.tfm 0 764)))
((TeX\ Blackboard\ Bold Oblique) ((bbmsl10.tfm 0 676) (bbmsl10.tfm 0 740)))
((TeX\ Blackboard\ Bold Regular) ((bbm10.tfm 0 560) (bbm10.tfm 0 624)))
((TeX\ Blackboard\ Bold\ Sans Bold) ((bbmssbx10.tfm 0 568) (bbmssbx10.tfm 0 644)))
((TeX\ Blackboard\ Bold\ Sans Italic) ((bbmssi10.tfm 0 708)))
((TeX\ Blackboard\ Bold\ Sans Regular) ((bbmss10.tfm 0 600) (bbmss10.tfm 0 664)))
((TeX\ Blackboard\ Bold\ Variant Regular) ((bbold10.tfm 0 788) (bbold10.tfm 0 852)))
((TeX\ Blackletter Regular) ((blackletter.tfm 0 720)))
((TeX\ Calligraphic Regular) ((callig15.tfm 0 1764)))
((TeX\ Calligraphic\ Capitals Bold) ((cmbsy10.tfm 0 1116)))
((TeX\ Calligraphic\ Capitals Regular) ((cmsy10.tfm 0 1124)))
((TeX\ Capital\ Baseball Regular) ((capbas.tfm 0 332)))
((TeX\ Children\ Handwriting Regular) ((la14.tfm 0 2292)))
((TeX\ Cypriot) ((cypr10.tfm 0 480)))
((TeX\ Double\ Stroke Regular) ((dsrom10.tfm 0 452)))
((TeX\ Double\ Stroke\ Sans Regular) ((dsss10.tfm 0 460)))
((TeX\ Duerer Bold) ((cdb10.tfm 0 360)))
((TeX\ Duerer Italic) ((cdi10.tfm 0 376)))
((TeX\ Duerer Oblique) ((cdsl10.tfm 0 360)))
((TeX\ Duerer Regular) ((cdr10.tfm 0 360)))
((TeX\ Duerer\ Mono Regular) ((cdtt10.tfm 0 192)))
((TeX\ Duerer\ Sans Regular) ((cdss10.tfm 0 360)))
((TeX\ Etruscan) ((etr10.tfm 0 388)))
((TeX\ Euler\ Calligraphic Regular) ((euxm10.tfm 0 904)))
((TeX\ German\ Handwriting Regular) ((twcal14.tfm 0 17516)))
((TeX\ Gothic Regular) ((ygoth.tfm 0 1300)))
((TeX\ Greek\ 4\ CBC) ((givbc10.tfm 0 428)))
((TeX\ Greek\ 6\ CBC) ((gvibc10.tfm 0 372)))
((TeX\ Gyre\ Adventor Bold) ((texgyreadventor-bold.otf 0 125784)))
((TeX\ Gyre\ Adventor Bold\ Italic) ((texgyreadventor-bolditalic.otf 0 127760)))
((TeX\ Gyre\ Adventor Italic) ((texgyreadventor-italic.otf 0 124888)))
((TeX\ Gyre\ Adventor Regular) ((texgyreadventor-regular.otf 0 124680)))
((TeX\ Gyre\ Bonum Bold) ((texgyrebonum-bold.otf 0 141140)))
((TeX\ Gyre\ Bonum Bold\ Italic) ((texgyrebonum-bolditalic.otf 0 145488)))
((TeX\ Gyre\ Bonum Italic) ((texgyrebonum-italic.otf 0 147120)))
((TeX\ Gyre\ Bonum Regular) ((texgyrebonum-regular.otf 0 142660)))
((TeX\ Gyre\ Bonum\ Math Regular) ((texgyrebonum-math.otf 0 527408)))
((TeX\ Gyre\ Chorus Regular) ((texgyrechorus-mediumitalic.otf 0 100924)))
((TeX\ Gyre\ Cursor Bold) ((texgyrecursor-bold.otf 0 87288)))
((TeX\ Gyre\ Cursor Bold\ Italic) ((texgyrecursor-bolditalic.otf 0 90360)))
((TeX\ Gyre\ Cursor Italic) ((texgyrecursor-italic.otf 0 87536)))
((TeX\ Gyre\ Cursor Regular) ((texgyrecursor-regular.otf 0 84652)))
((TeX\ Gyre\ Heros Bold) ((texgyreheros-bold.otf 0 135204)))
((TeX\ Gyre\ Heros Bold\ Italic) ((texgyreheros-bolditalic.otf 0 135264)))
((TeX\ Gyre\ Heros Italic) ((texgyreheros-italic.otf 0 139208)))
((TeX\ Gyre\ Heros Regular) ((texgyreheros-regular.otf 0 133600)))
((TeX\ Gyre\ Heros\ Cn Bold) ((texgyreheroscn-bold.otf 0 133220)))
((TeX\ Gyre\ Heros\ Cn Bold\ Italic) ((texgyreheroscn-bolditalic.otf 0 138876)))
((TeX\ Gyre\ Heros\ Cn Italic) ((texgyreheroscn-italic.otf 0 138940)))
((TeX\ Gyre\ Heros\ Cn Regular) ((texgyreheroscn-regular.otf 0 132372)))
((TeX\ Gyre\ Pagella Bold) ((texgyrepagella-bold.otf 0 143844)))
((TeX\ Gyre\ Pagella Bold\ Italic) ((texgyrepagella-bolditalic.otf 0 134516)))
((TeX\ Gyre\ Pagella Italic) ((texgyrepagella-italic.otf 0 146432)))
((TeX\ Gyre\ Pagella Regular) ((texgyrepagella-regular.otf 0 144472)))
((TeX\ Gyre\ Pagella\ Math Regular) ((texgyrepagella-math.otf 0 601220)))
((TeX\ Gyre\ Schola Bold) ((texgyreschola-bold.otf 0 141752)))
((TeX\ Gyre\ Schola Bold\ Italic) ((texgyreschola-bolditalic.otf 0 144864)))
((TeX\ Gyre\ Schola Italic) ((texgyreschola-italic.otf 0 143152)))
((TeX\ Gyre\ Schola Regular) ((texgyreschola-regular.otf 0 140596)))
((TeX\ Gyre\ Schola\ Math Regular) ((texgyreschola-math.otf 0 596860)))
((TeX\ Gyre\ Termes Bold) ((texgyretermes-bold.otf 0 139480)))
((TeX\ Gyre\ Termes Bold\ Italic) ((texgyretermes-bolditalic.otf 0 144180)))
((TeX\ Gyre\ Termes Italic) ((texgyretermes-italic.otf 0 141324)))
((TeX\ Gyre\ Termes Regular) ((texgyretermes-regular.otf 0 140932)))
((TeX\ Gyre\ Termes\ Math Regular) ((texgyretermes-math.otf 0 532404)))
((TeX\ Hershey Regular) ((hscs10.tfm 0 0)))
((TeX\ Linear\ B) ((linb10.tfm 0 972)))
((TeX\ Ogham) ((ogham10.tfm 0 360)))
((TeX\ Old\ English Regular) ((hge10.tfm 0 696)))
((TeX\ Pacioli Oblique) ((cpcsl10.tfm 0 824) (cpcsl10.tfm 0 760)))
((TeX\ Pacioli Regular) ((cpcr10.tfm 0 784) (cpcr10.tfm 0 720)))
((TeX\ Pandora Bold) ((pnb10.tfm 0 1892)))
((TeX\ Pandora Oblique) ((pnsl10.tfm 1896)))
((TeX\ Pandora Regular) ((pnr10.tfm 0 1896)))
((TeX\ Pandora\ Mono Regular) ((pntt9.tfm 720)))
((TeX\ Pandora\ Sans Bold) ((pnssb10.tfm 1888)))
((TeX\ Pandora\ Sans Italic) ((pnssi10.tfm 1892)))
((TeX\ Pandora\ Sans Regular) ((pnss10.tfm 1892)))
((TeX\ Phoenician) ((phnc10.tfm 0 496)))
((TeX\ Punk Bold) ((punkbx20.tfm 0 740) (punkbx20.tfm 0 676)))
((TeX\ Punk Oblique) ((punksl20.tfm 0 748) (punksl20.tfm 0 684)))
((TeX\ Punk Regular) ((punk20.tfm 0 740) (punk20.tfm 0 676)))
((TeX\ Ralph\ Smith Regular) ((rsfs10.tfm 0 688) (rsfs10.tfm 0 752)))
((TeX\ Runic\ Futharc) ((fut10.tfm 0 504)))
((TeX\ Runic\ Futhol) ((futhol10.tfm 0 280)))
((TeX\ Runic\ Futhor) ((futhor10.tfm 0 280)))
((TeX\ Schwell Regular) ((schwell.tfm 0 2192)))
((TeX\ Slavonic) ((izhitsa10.tfm 0 0)))
((TeX\ Southarabian) ((SouthArabian.tfm 0 0)))
((TeX\ Suet Regular) ((suet14.tfm 0 2104)))
((TeX\ Swab Regular) ((yswab.tfm 0 1440)))
((TeX\ Syriac) ((estrangelo.tfm 0 0)))
((TeX\ Ugaritic) ((ugarithic.tfm 0 504)))
((TeX\ Va\ Handwriting Regular) ((va14.tfm 0 2100)))
((TeXmacs\ Avant\ Garde Bold) ((avant-garde-bx10.tfm 0 5856)))
((TeXmacs\ Avant\ Garde Bold\ Italic) ((avant-garde-bi10.tfm 0 6124)))
((TeXmacs\ Avant\ Garde Italic) ((avant-garde-ti10.tfm 0 6264)))
((TeXmacs\ Avant\ Garde Regular) ((avant-garde-rm10.tfm 0 6124)))
((TeXmacs\ Bookman Bold) ((bookman-bx10.tfm 0 5888)))
((TeXmacs\ Bookman Bold\ Italic) ((bookman-bi10.tfm 0 6264)))
((TeXmacs\ Bookman Italic) ((bookman-ti10.tfm 0 6284)))
((TeXmacs\ Bookman Regular) ((bookman-rm10.tfm 0 5996)))
((TeXmacs\ Computer\ Modern Bold) ((ecbx10.tfm 0 3200)))
((TeXmacs\ Computer\ Modern Bold\ Condensed) ((ecrb10.tfm 0 3196)))
((TeXmacs\ Computer\ Modern Bold\ Italic) ((ecbi10.tfm 0 2900)))
((TeXmacs\ Computer\ Modern Bold\ Oblique) ((ecbl10.tfm 0 3412)))
((TeXmacs\ Computer\ Modern Bold\ Oblique\ SmallCaps) ((ecoc10.tfm 0 3060)))
((TeXmacs\ Computer\ Modern Bold\ SmallCaps) ((ecxc10.tfm 0 2852)))
((TeXmacs\ Computer\ Modern Italic) ((ecti10.tfm 0 2840)))
((TeXmacs\ Computer\ Modern ItalicUpright) ((ecui10.tfm 3072)))
((TeXmacs\ Computer\ Modern Long) ((ecdh10.tfm 0 3152)))
((TeXmacs\ Computer\ Modern Oblique) ((ecsl10.tfm 0 3372)))
((TeXmacs\ Computer\ Modern Regular) ((ecrm10.tfm 0 3148)))
((TeXmacs\ Computer\ Modern SmallCaps) ((eccc10.tfm 0 2788)))
((TeXmacs\ Computer\ Modern\ Mono Flat) ((ecltt10.tfm 0 1536)))
((TeXmacs\ Computer\ Modern\ Mono Italic\ Proportional) ((ecvi10.tfm 0 2752)))
((TeXmacs\ Computer\ Modern\ Mono Oblique) ((ecst10.tfm 0 1356)))
((TeXmacs\ Computer\ Modern\ Mono Proportional) ((ecvt10.tfm 0 3104)))
((TeXmacs\ Computer\ Modern\ Mono Regular) ((ectt10.tfm 0 1348)))
((TeXmacs\ Computer\ Modern\ Mono SmallCaps) ((ectc10.tfm 0 1352)))
((TeXmacs\ Computer\ Modern\ Sans Bold) ((ecsx10.tfm 0 3132)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Condensed) ((ecssdc10.tfm 0 3128)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Flat) ((eclb10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Italic\ Flat) ((eclo10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Oblique) ((ecso10.tfm 0 3352)))
((TeXmacs\ Computer\ Modern\ Sans Flat) ((eclq10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Italic\ Flat) ((ecli10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Oblique) ((ecsi10.tfm 0 3360)))
((TeXmacs\ Computer\ Modern\ Sans Regular) ((ecss10.tfm 0 3140)))
((TeXmacs\ Concrete Bold) ((ecbx10.tfm 0 3200)))
((TeXmacs\ Concrete Bold\ Condensed) ((ecrb10.tfm 0 3196)))
((TeXmacs\ Concrete Bold\ Italic) ((ecbi10.tfm 0 2900)))
((TeXmacs\ Concrete Bold\ Oblique) ((ecbl10.tfm 0 3412)))
((TeXmacs\ Concrete Italic) ((eoti10.tfm 0 2868)))
((TeXmacs\ Concrete Oblique) ((eosl10.tfm 0 3440)))
((TeXmacs\ Concrete Regular) ((eorm10.tfm 0 3220)))
((TeXmacs\ Concrete SmallCaps) ((eocc10.tfm 0 2812)))
((TeXmacs\ Concrete\ Mono Oblique) ((ecst10.tfm 0 1356)))
((TeXmacs\ Concrete\ Mono Proportional) ((ecvt10.tfm 0 3104)))
((TeXmacs\ Concrete\ Mono Regular) ((ectt10.tfm 0 2011)))
((TeXmacs\ Concrete\ Mono SmallCaps) ((ectc10.tfm 0 1352)))
((TeXmacs\ Concrete\ Sans Bold) ((ecsx10.tfm 0 3132)))
((TeXmacs\ Concrete\ Sans Oblique) ((etsi10.tfm 0 3360)))
((TeXmacs\ Concrete\ Sans Regular) ((ecss10.tfm 0 3140)))
((TeXmacs\ Courier Bold) ((courier-bx10.tfm 0 1328)))
((TeXmacs\ Courier Bold\ Italic) ((courier-bi10.tfm 0 1580)))
((TeXmacs\ Courier Italic) ((courier-ti10.tfm 0 1488)))
((TeXmacs\ Courier Regular) ((courier-rm10.tfm 0 1328)))
((TeXmacs\ Euler Bold) ((eufb10.tfm 0 1028)))
((TeXmacs\ Euler Regular) ((eufm10.tfm 0 1040)))
((TeXmacs\ Euler\ New\ Roman Bold) ((eurb10.tfm 0 1208)))
((TeXmacs\ Euler\ New\ Roman Regular) ((eurm10.tfm 0 1228)))
((TeXmacs\ Helvetica Bold) ((helvetica-bx10.tfm 0 40892)))
((TeXmacs\ Helvetica Bold\ Italic) ((helvetica-bi10.tfm 0 41140)))
((TeXmacs\ Helvetica Italic) ((helvetica-ti10.tfm 0 41164)))
((TeXmacs\ Helvetica Regular) ((helvetica-rm10.tfm 0 40928)))
((TeXmacs\ New\ Century\ Schoolbook Bold) ((nc-schoolbook-bx10.tfm 0 5900)))
((TeXmacs\ New\ Century\ Schoolbook Bold\ Italic) ((nc-schoolbook-bi10.tfm 0 6096)))
((TeXmacs\ New\ Century\ Schoolbook Italic) ((nc-schoolbook-ti10.tfm 0 6092)))
((TeXmacs\ New\ Century\ Schoolbook Regular) ((nc-schoolbook-rm10.tfm 0 5936)))
((TeXmacs\ Palatino Bold) ((palatino-bx10.tfm 0 3296)))
((TeXmacs\ Palatino Bold\ Italic) ((palatino-bi10.tfm 0 3628)))
((TeXmacs\ Palatino Bold\ Oblique) ((palatino-bl10.tfm 0 3296)))
((TeXmacs\ Palatino Bold\ SmallCaps) ((palatino-xc10.tfm 0 5544)))
((TeXmacs\ Palatino Italic) ((palatino-ti10.tfm 0 3536)))
((TeXmacs\ Palatino Oblique) ((palatino-sl10.tfm 0 3648)))
((TeXmacs\ Palatino Regular) ((palatino-rm10.tfm 0 3648)))
((TeXmacs\ Palatino SmallCaps) ((palatino-cc10.tfm 0 6108)))
((TeXmacs\ Times Bold) ((times-bx10.tfm 0 64028)))
((TeXmacs\ Times Bold\ Italic) ((times-bi10.tfm 0 66560)))
((TeXmacs\ Times Bold\ Oblique) ((times-bl10.tfm 0 64280)))
((TeXmacs\ Times Bold\ SmallCaps) ((times-xc10.tfm 0 1508)))
((TeXmacs\ Times Italic) ((times-ti10.tfm 0 69636)))
((TeXmacs\ Times Oblique) ((times-sl10.tfm 0 66036)))
((TeXmacs\ Times Regular) ((times-rm10.tfm 0 65812)))
((TeXmacs\ Times SmallCaps) ((times-cc10.tfm 0 1540)))
((Thickhead Regular) ((THICKHEA.ttf 0 34852)))
((Thonburi Bold) ((ThonburiBold.ttf 0 255412) (Thonburi.ttc 1 2411184) (ThonburiBold.ttf 0 256856)))
((Thonburi Light) ((Thonburi.ttc 2 2411184)))
((Thonburi Regular) ((Thonburi.ttf 0 223404) (Thonburi.ttc 0 2411184) (Thonburi.ttf 0 224784)))
((Times\ New\ Roman Bold) ((Times\ New\ Roman\ Bold.ttf 0 842168) (timesbd.ttf 0 398372)))
((Times\ New\ Roman Bold\ Italic) ((Times\ New\ Roman\ Bold\ Italic.ttf 0 620008) (timesbi.ttf 0 239692)))
((Times\ New\ Roman Italic) ((Times\ New\ Roman\ Italic.ttf 0 660268) (timesi.ttf 0 248368)))
((Times\ New\ Roman Regular) ((Times\ New\ Roman.ttf 0 834452) (times.ttf 0 409280)))
((Tlwg\ Typist Bold) ((TlwgTypist-Bold.ttf 0 96040)))
((Tlwg\ Typist BoldOblique) ((TlwgTypist-BoldOblique.ttf 0 108408)))
((Tlwg\ Typist Medium) ((TlwgTypist.ttf 0 92472)))
((Tlwg\ Typist Oblique) ((TlwgTypist-Oblique.ttf 0 107864)))
((Tlwg\ Typo Bold) ((TlwgTypo-Bold.ttf 0 96096)))
((Tlwg\ Typo BoldOblique) ((TlwgTypo-BoldOblique.ttf 0 108368)))
((Tlwg\ Typo Medium) ((TlwgTypo.ttf 0 92508)))
((Tlwg\ Typo Oblique) ((TlwgTypo-Oblique.ttf 0 108332)))
((TlwgMono Bold) ((TlwgMono-Bold.ttf 0 90652)))
((TlwgMono BoldOblique) ((TlwgMono-BoldOblique.ttf 0 100156)))
((TlwgMono Medium) ((TlwgMono.ttf 0 83804)))
((TlwgMono Oblique) ((TlwgMono-Oblique.ttf 0 99016)))
((TlwgTypewriter Bold) ((TlwgTypewriter-Bold.ttf 0 93908)))
((TlwgTypewriter BoldOblique) ((TlwgTypewriter-BoldOblique.ttf 0 102652)))
((TlwgTypewriter Medium) ((TlwgTypewriter.ttf 0 86976)))
((TlwgTypewriter Oblique) ((TlwgTypewriter-Oblique.ttf 0 101520)))
((Trattatello Regular) ((Trattatello.ttf 0 1160004)))
((Trebuchet\ MS Bold) ((Trebuchet\ MS\ Bold.ttf 0 129360) (trebucbd.ttf 0 123096)))
((Trebuchet\ MS Bold\ Italic) ((Trebuchet\ MS\ Bold\ Italic.ttf 0 137008) (trebucbi.ttf 0 131188)))
((Trebuchet\ MS Italic) ((Trebuchet\ MS\ Italic.ttf 0 144820) (trebucit.ttf 0 139288)))
((Trebuchet\ MS Regular) ((Trebuchet\ MS.ttf 0 138848) (trebuc.ttf 0 134108)))
((TriangleETcircle\ Shadow Regular) ((TriangleETcircle\ Shadow.otf 0 39260)))
((TriangleETcircle\ Shadowed Regular) ((TriangleETcircle\ Shadowed.otf 0 23844)))
((Tsukushi\ A\ Round\ Gothic Bold) ((TsukushiAMaruGothic.ttc 1 7916648)))
((Tsukushi\ A\ Round\ Gothic Regular) ((TsukushiAMaruGothic.ttc 0 7916648)))
((Tsukushi\ B\ Round\ Gothic Bold) ((TsukushiBMaruGothic.ttc 1 7980496)))
((Tsukushi\ B\ Round\ Gothic Regular) ((TsukushiBMaruGothic.ttc 0 7980496)))
((Tt-Kp Medium) ((TT-KP-ME.ttf 0 26928)))
((Tt-Kp Regular) ((TT-KP-RE.ttf 0 27044)))
((Tuffy Bold) ((Tuffy_Bold.otf 0 21904) (Tuffy_Bold.ttf 0 17196)))
((Tuffy Bold-Italic) ((Tuffy_Bold_Italic.otf 0 32456) (Tuffy_Bold_Italic.ttf 0 18828)))
((Tuffy Italic) ((Tuffy_Italic.otf 0 24464) (Tuffy_Italic.ttf 0 19284)))
((Tuffy Regular) ((Tuffy.otf 0 18900) (Tuffy.ttf 0 18444)))
((Tunga Regular) ((tunga.ttf 0 148624)))
((Ubuntu Bold) ((Ubuntu-B.ttf 0 312932)))
((Ubuntu Bold\ Italic) ((Ubuntu-BI.ttf 0 400740)))
((Ubuntu Italic) ((Ubuntu-I.ttf 0 349560)))
((Ubuntu Regular) ((Ubuntu-R.ttf 0 318280)))
((Ubuntu-Title Title) ((Ubuntu-Title.ttf 0 15108)))
((Ubuntu-Title-fr Title-fr) ((ubuntu-title-fr-1.1.ttf 0 22268)))
((Umpush Bold) ((Umpush-Bold.ttf 0 68016)))
((Umpush BoldOblique) ((Umpush-BoldOblique.ttf 0 80156)))
((Umpush Book) ((Umpush.ttf 0 69964)))
((Umpush Light) ((Umpush-Light.ttf 0 69896)))
((Umpush LightOblique) ((Umpush-LightOblique.ttf 0 82852)))
((Umpush Oblique) ((Umpush-Oblique.ttf 0 82692)))
((UnBatang Bold) ((UnBatangBold.ttf 0 3863046) (UnBatangBold.ttf 0 4071104)))
((UnBatang Regular) ((UnBatang.ttf 0 3678974)))
((UnDotum Bold) ((UnDotumBold.ttf 0 2603854) (UnDotumBold.ttf 0 2808292)))
((UnDotum Regular) ((UnDotum.ttf 0 2209390)))
((UnGraphic Bold) ((UnGraphicBold.ttf 0 768906)))
((UnGraphic Regular) ((UnGraphic.ttf 0 788458)))
((UnGungseo Regular) ((UnGungseo.ttf 0 4149866)))
((UnPilgi Bold) ((UnPilgiBold.ttf 0 654486)))
((UnPilgi Regular) ((UnPilgi.ttf 0 660502)))
((Utkal Medium) ((utkal.ttf 0 156500)))
((Verdana Bold) ((Verdana\ Bold.ttf 0 153260) (verdanab.ttf 0 137616)))
((Verdana Bold\ Italic) ((Verdana\ Bold\ Italic.ttf 0 173132) (verdanaz.ttf 0 154800)))
((Verdana Italic) ((Verdana\ Italic.ttf 0 174612) (verdanai.ttf 0 155076)))
((Verdana Regular) ((Verdana.ttf 0 186188) (verdana.ttf 0 171792)))
((Verily\ Serif\ Mono Book) ((VerilySerifMono.otf 0 45800)))
((Vermi\ di\ Rouge Regular) ((vermidirouge\ 1.0.ttf 0 60248)))
((Victor Regular) ((Victor.otf 0 155008)))
((Vipond\ Angular Regular) ((vipond_angular.ttf 0 20892)))
((Vipond\ Octic Regular) ((vipond_octic.ttf 0 17292)))
((Vrinda Regular) ((vrinda.ttf 0 252820)))
((Waree Bold) ((Waree-Bold.ttf 0 85352)))
((Waree BoldOblique) ((Waree-BoldOblique.ttf 0 96324)))
((Waree Book) ((Waree.ttf 0 86772)))
((Waree Oblique) ((Waree-Oblique.ttf 0 99456)))
((Waseem Light) ((Waseem.ttc 1 368184)))
((Waseem Regular) ((Waseem.ttc 0 368184)))
((Wawati\ SC Regular) ((WawaSC-Regular.otf 0 17435944)))
((Wawati\ TC Regular) ((WawaTC-Regular.otf 0 17488424)))
((Webdings Regular) ((Webdings.ttf 0 124308) (webdings.ttf 0 118752)))
((WeblySleek\ UI Light) ((weblysleekuil.ttf 0 676412)))
((WeblySleek\ UI Light\ Italic) ((weblysleekuili.ttf 0 396444)))
((WeblySleek\ UI SemiBold) ((weblysleekuisb.ttf 0 655596)))
((WeblySleek\ UI SemiBold\ Italic) ((weblysleekuisbi.ttf 0 394584)))
((WeblySleek\ UI SemiLight) ((weblysleekuisl.ttf 0 622892)))
((WeblySleek\ UI SemiLight\ Italic) ((weblysleekuisli.ttf 0 404012)))
((Weibei\ SC Bold) ((WeibeiSC-Bold.otf 0 24058332)))
((Weibei\ TC Bold) ((WeibeiTC-Bold.otf 0 14896268)))
((WenQuanYi\ Micro\ Hei Regular) ((wqy-microhei.ttc 0 5177387)))
((WenQuanYi\ Micro\ Hei\ Mono Regular) ((wqy-microhei.ttc 1)))
((WenQuanYi\ Zen\ Hei Medium) ((wqy-zenhei.ttf 0 10808952)))
((Wingdings Regular) ((Wingdings.ttf 0 86384) (wingding.ttf 0 81000)))
((Wingdings\ 2 Regular) ((Wingdings\ 2.ttf 0 68768)))
((Wingdings\ 3 Regular) ((Wingdings\ 3.ttf 0 38308)))
((Wolgast\ Two Bold) ((Wolgast\ Two\ Bold.otf 0 52148)))
((Wolgast\ Two Normal) ((Wolgast\ Two\ Normal.otf 0 44244)))
((Xingkai\ SC Bold) ((Xingkai.ttc 0 14454688)))
((Xingkai\ SC Light) ((Xingkai.ttc 1 14454688)))
((Yiggivoo\ Unicode Regular) ((Yiggivoo\ UC.ttf 0 213120)))
((Yiggivoo\ Unicode\  Italic) ((Yiggivoo\ UC_I.ttf 0 181960)))
((Yiggivoo\ Unicode\ 3D Italic) ((Yiggivoo\ UC_I_3D.ttf 0 283268)))
((Yiggivoo\ Unicode\ 3D Regular) ((Yiggivoo\ UC\ 3D.ttf 0 451884)))
((Yokawerad Regular) ((Yokawerad.otf 0 382696)))
((YouYuan Regular) ((simyou.ttf 0 6700204)))
((Yuanti\ SC Bold) ((Yuanti.ttc 0 78417612)))
((Yuanti\ SC Light) ((Yuanti.ttc 2 78417612)))
((Yuanti\ SC Regular) ((Yuanti.ttc 4 78417612)))
((Yuanti\ TC Bold) ((Yuanti.ttc 1 78417612)))
((Yuanti\ TC Light) ((Yuanti.ttc 3 78417612)))
((Yuanti\ TC Regular) ((Yuanti.ttc 5 78417612)))
((YuGothic Bold) ((Yu\ Gothic\ Bold.otf 0 8160676)))
((YuGothic Medium) ((Yu\ Gothic\ Medium.otf 0 8218324)))
((YuMincho Demibold) ((YuMincho.ttc 1 21174132)))
((YuMincho Medium) ((YuMincho.ttc 0 21174132)))
((YuMincho\ +36p\ Kana Demibold) ((YuMincho.ttc 3 21174132)))
((YuMincho\ +36p\ Kana Medium) ((YuMincho.ttc 2 21174132)))
((Yuppy\ SC Regular) ((YuppySC-Regular.otf 0 3509868) (雅痞-简.otf 0 3509868)))
((Yuppy\ TC Regular) ((YuppyTC-Regular.otf 0 5320088) (雅痞-繁.otf 0 5320088)))
((Zantroke Regular) ((Zantroke.otf 0 282524)))
((Zapf\ Dingbats Regular) ((ZapfDingbats.ttf 0 154496) (ZapfDingbats.ttf 0 154132)))
((Zapfino Regular) ((Zapfino.ttf 0 528844) (Zapfino.ttf 0 398884)))
((Znikomit Regular) ((Znikomit.otf 0 677128)))
((ZnikomitNo24 Regular) ((ZnikomitNo24.otf 0 777128)))
((ZnikomitNo24 Thin) ((ZnikomitNo24Thin.otf 0 841584)))
